# These functions compute the expected arrival rate, E[ lambda(N) ].
# There are separate functions depending on which supply groups are present.
# Arguments:
#  lambda = parameters
#  index = individuals being evaluated
#  ED = search probabilities (for entire estimation sample)



### SIMULATION DRAWS FOR ARRIVAL RATE (in likelihood)

# Number of draws (per person in supply group):

S.supply <- 50

# Draws for types:

Unif.w <- matrix(runif(n*S.supply),n,S.supply)

# Draws for search decision:

Unif.d <- matrix(runif(n*S.supply),n,S.supply)



### ALL 3 SUPPLY GROUPS

Elam.3supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi2 <- M2[[i]]; Mi3 <- M3[[i]]
  n.m1 <- length(Mi1); n.m2 <- length(Mi2); n.m3 <- length(Mi3)
  Nbar.m1 <- 0; Nbar.m2 <- 0; Nbar.m3 <- 0
  Nvirg.m1 <- 0; Nvirg.m2 <- 0; Nvirg.m3 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
Nbar.m1 <- Nvirg.m1/n.m1 + (n.m1 - nvirg.m1)/n.m1
    }
  # M2) Grade below/above:
if (n.m2 > 0)  {
  ED.m2 <- rbind(ED[Mi2,]); virg.m2 <- which(ED.m2[,1] < 1); nvirg.m2 <- length(virg.m2)
  if (nvirg.m2 > 0)  {
K.m2 <- rbind( (Unif.w[Mi2[virg.m2],] > PI[Mi2[virg.m2],1]) + 
               (Unif.w[Mi2[virg.m2],] > CDF.w2[Mi2[virg.m2]]) )
I.m2 <- row(K.m2) + nvirg.m2*K.m2
Dsim.m2 <- matrix(ED.m2[virg.m2,][I.m2], nvirg.m2, S.supply)  >  Unif.d[Mi2[virg.m2],]
Nvirg.m2 <- colSums(Dsim.m2, na.rm=TRUE)
      }
Nbar.m2 <- Nvirg.m2/n.m2 + (n.m2 - nvirg.m2)/n.m2
    }
  # M3) Grade above / two above:
if (n.m3 > 0)  {
  ED.m3 <- rbind(ED[Mi3,]); virg.m3 <- which(ED.m3[,1] < 1); nvirg.m3 <- length(virg.m3)
  if (nvirg.m3 > 0)  {
K.m3 <- rbind( (Unif.w[Mi3[virg.m3],] > PI[Mi3[virg.m3],1]) + 
               (Unif.w[Mi3[virg.m3],] > CDF.w2[Mi3[virg.m3]]) )
I.m3 <- row(K.m3) + nvirg.m3*K.m3
Dsim.m3 <- matrix(ED.m3[virg.m3,][I.m3], nvirg.m3, S.supply)  >  Unif.d[Mi3[virg.m3],]
Nvirg.m3 <- colSums(Dsim.m3, na.rm=TRUE)
      }
Nbar.m3 <- Nvirg.m3/n.m3 + (n.m3 - nvirg.m3)/n.m3
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(Nbar.m1,Nbar.m2,Nbar.m3) ) )
  }
Elam
}  #  END  Elam.3supply



### TWO SUPPLY GROUPS

Elam.2supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi2 <- M2[[i]]
  n.m1 <- length(Mi1); n.m2 <- length(Mi2)
  Nbar.m1 <- 0; Nbar.m2 <- 0
  Nvirg.m1 <- 0; Nvirg.m2 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
Nbar.m1 <- Nvirg.m1/n.m1 + (n.m1 - nvirg.m1)/n.m1
    }
  # M2) Grade below/above:
if (n.m2 > 0)  {
  ED.m2 <- rbind(ED[Mi2,]); virg.m2 <- which(ED.m2[,1] < 1); nvirg.m2 <- length(virg.m2)
  if (nvirg.m2 > 0)  {
K.m2 <- rbind( (Unif.w[Mi2[virg.m2],] > PI[Mi2[virg.m2],1]) + 
               (Unif.w[Mi2[virg.m2],] > CDF.w2[Mi2[virg.m2]]) )
I.m2 <- row(K.m2) + nvirg.m2*K.m2
Dsim.m2 <- matrix(ED.m2[virg.m2,][I.m2], nvirg.m2, S.supply)  >  Unif.d[Mi2[virg.m2],]
Nvirg.m2 <- colSums(Dsim.m2, na.rm=TRUE)
      }
Nbar.m2 <- Nvirg.m2/n.m2 + (n.m2 - nvirg.m2)/n.m2
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(Nbar.m1,Nbar.m2) ) )
  }
Elam
}  #  END  Elam.2supply



### ONE SUPPLY GROUP

Elam.1supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)( 0 ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]
  n.m1 <- length(Mi1)
  Nbar.m1 <- 0
  Nvirg.m1 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
Nbar.m1 <- Nvirg.m1/n.m1 + (n.m1 - nvirg.m1)/n.m1
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(Nbar.m1) ) )
  }
Elam
}  #  END  Elam.1supply



### SPLIT SUPPLY GROUPS

Elam.splitsup <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi3 <- M3[[i]]
  n.m1 <- length(Mi1); n.m3 <- length(Mi3)
  Nbar.m1 <- 0; Nbar.m3 <- 0
  Nvirg.m1 <- 0; Nvirg.m3 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
Nbar.m1 <- Nvirg.m1/n.m1 + (n.m1 - nvirg.m1)/n.m1
    }
  # M3) Grade above / two above:
if (n.m3 > 0)  {
  ED.m3 <- rbind(ED[Mi3,]); virg.m3 <- which(ED.m3[,1] < 1); nvirg.m3 <- length(virg.m3)
  if (nvirg.m3 > 0)  {
K.m3 <- rbind( (Unif.w[Mi3[virg.m3],] > PI[Mi3[virg.m3],1]) + 
               (Unif.w[Mi3[virg.m3],] > CDF.w2[Mi3[virg.m3]]) )
I.m3 <- row(K.m3) + nvirg.m3*K.m3
Dsim.m3 <- matrix(ED.m3[virg.m3,][I.m3], nvirg.m3, S.supply)  >  Unif.d[Mi3[virg.m3],]
Nvirg.m3 <- colSums(Dsim.m3, na.rm=TRUE)
      }
Nbar.m3 <- Nvirg.m3/n.m3 + (n.m3 - nvirg.m3)/n.m3
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(Nbar.m1,Nbar.m3) ) )
  }
Elam
}  #  END  Elam.splitsup

