# These functions compute the expected arrival rate, E[ lambda(N) ],
#   for the model with competition in the matching function.
# There are separate functions depending on which supply groups are present.
# Arguments:
#  lambda = parameters
#  index = individuals being evaluated
#  ED = search probabilities (for entire estimation sample)

# The same simulation draws from the original specification are also used here.



### ALL 3 SUPPLY GROUPS

Elam.3supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi2 <- M2[[i]]; Mi3 <- M3[[i]]
  Ci1 <- C1[[i]]; Ci2 <- C2[[i]]; Ci3 <- C3[[i]]
  n.m1 <- length(Mi1); n.m2 <- length(Mi2); n.m3 <- length(Mi3)
  n.c1 <- length(Ci1); n.c2 <- length(Ci2); n.c3 <- length(Ci3)
  N.m1 <- 0; N.m2 <- 0; N.m3 <- 0
  Nvirg.m1 <- 0; Nvirg.m2 <- 0; Nvirg.m3 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
N.m1 <- Nvirg.m1 + (n.m1 - nvirg.m1)
    }
  # C1) Same grade:
if (n.c1 > 0)  {
  ED.c1 <- rbind(ED[Ci1,]); virg.c1 <- which(ED.c1[,1] < 1); nvirg.c1 <- length(virg.c1)
  if (nvirg.c1 > 0)  {
K.c1 <- rbind( (Unif.w[Ci1[virg.c1],] > PI[Ci1[virg.c1],1]) + 
               (Unif.w[Ci1[virg.c1],] > CDF.w2[Ci1[virg.c1]]) )
I.c1 <- row(K.c1) + nvirg.c1*K.c1
Dsim.c1 <- matrix(ED.c1[virg.c1,][I.c1], nvirg.c1, S.supply)  >  Unif.d[Ci1[virg.c1],]
Nvirg.c1 <- colSums(Dsim.c1, na.rm=TRUE)
      }
N.m1 <- N.m1 / pmax(Nvirg.c1 + (n.c1 - nvirg.c1),1)
    }
  # M2) Grade below/above:
if (n.m2 > 0)  {
  ED.m2 <- rbind(ED[Mi2,]); virg.m2 <- which(ED.m2[,1] < 1); nvirg.m2 <- length(virg.m2)
  if (nvirg.m2 > 0)  {
K.m2 <- rbind( (Unif.w[Mi2[virg.m2],] > PI[Mi2[virg.m2],1]) + 
               (Unif.w[Mi2[virg.m2],] > CDF.w2[Mi2[virg.m2]]) )
I.m2 <- row(K.m2) + nvirg.m2*K.m2
Dsim.m2 <- matrix(ED.m2[virg.m2,][I.m2], nvirg.m2, S.supply)  >  Unif.d[Mi2[virg.m2],]
Nvirg.m2 <- colSums(Dsim.m2, na.rm=TRUE)
      }
N.m2 <- Nvirg.m2 + (n.m2 - nvirg.m2)
    }
  # C2) Grade below/above:
if (n.c2 > 0)  {
  ED.c2 <- rbind(ED[Ci2,]); virg.c2 <- which(ED.c2[,1] < 1); nvirg.c2 <- length(virg.c2)
  if (nvirg.c2 > 0)  {
K.c2 <- rbind( (Unif.w[Ci2[virg.c2],] > PI[Ci2[virg.c2],1]) + 
               (Unif.w[Ci2[virg.c2],] > CDF.w2[Ci2[virg.c2]]) )
I.c2 <- row(K.c2) + nvirg.c2*K.c2
Dsim.c2 <- matrix(ED.c2[virg.c2,][I.c2], nvirg.c2, S.supply)  >  Unif.d[Ci2[virg.c2],]
Nvirg.c2 <- colSums(Dsim.c2, na.rm=TRUE)
      }
N.m2 <- N.m2 / pmax(Nvirg.c2 + (n.c2 - nvirg.c2),1)
    }
  # M3) Grade above / two above:
if (n.m3 > 0)  {
  ED.m3 <- rbind(ED[Mi3,]); virg.m3 <- which(ED.m3[,1] < 1); nvirg.m3 <- length(virg.m3)
  if (nvirg.m3 > 0)  {
K.m3 <- rbind( (Unif.w[Mi3[virg.m3],] > PI[Mi3[virg.m3],1]) + 
               (Unif.w[Mi3[virg.m3],] > CDF.w2[Mi3[virg.m3]]) )
I.m3 <- row(K.m3) + nvirg.m3*K.m3
Dsim.m3 <- matrix(ED.m3[virg.m3,][I.m3], nvirg.m3, S.supply)  >  Unif.d[Mi3[virg.m3],]
Nvirg.m3 <- colSums(Dsim.m3, na.rm=TRUE)
      }
N.m3 <- Nvirg.m3 + (n.m3 - nvirg.m3)
    }
  # C3) Grade above / two above:
if (n.c3 > 0)  {
  ED.c3 <- rbind(ED[Ci3,]); virg.c3 <- which(ED.c3[,1] < 1); nvirg.c3 <- length(virg.c3)
  if (nvirg.c3 > 0)  {
K.c3 <- rbind( (Unif.w[Ci3[virg.c3],] > PI[Ci3[virg.c3],1]) + 
               (Unif.w[Ci3[virg.c3],] > CDF.w2[Ci3[virg.c3]]) )
I.c3 <- row(K.c3) + nvirg.c3*K.c3
Dsim.c3 <- matrix(ED.c3[virg.c3,][I.c3], nvirg.c3, S.supply)  >  Unif.d[Ci3[virg.c3],]
Nvirg.c3 <- colSums(Dsim.c3, na.rm=TRUE)
      }
N.m3 <- N.m3 / pmax(Nvirg.c3 + (n.c3 - nvirg.c3),1)
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(N.m1,N.m2,N.m3) ) )
  }
Elam
}  #  END  Elam.3supply



### TWO SUPPLY GROUPS

Elam.2supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi2 <- M2[[i]]
  Ci1 <- C1[[i]]; Ci2 <- C2[[i]]
  n.m1 <- length(Mi1); n.m2 <- length(Mi2)
  n.c1 <- length(Ci1); n.c2 <- length(Ci2)
  N.m1 <- 0; N.m2 <- 0
  Nvirg.m1 <- 0; Nvirg.m2 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
N.m1 <- Nvirg.m1 + (n.m1 - nvirg.m1)
    }
  # C1) Same grade:
if (n.c1 > 0)  {
  ED.c1 <- rbind(ED[Ci1,]); virg.c1 <- which(ED.c1[,1] < 1); nvirg.c1 <- length(virg.c1)
  if (nvirg.c1 > 0)  {
K.c1 <- rbind( (Unif.w[Ci1[virg.c1],] > PI[Ci1[virg.c1],1]) + 
               (Unif.w[Ci1[virg.c1],] > CDF.w2[Ci1[virg.c1]]) )
I.c1 <- row(K.c1) + nvirg.c1*K.c1
Dsim.c1 <- matrix(ED.c1[virg.c1,][I.c1], nvirg.c1, S.supply)  >  Unif.d[Ci1[virg.c1],]
Nvirg.c1 <- colSums(Dsim.c1, na.rm=TRUE)
      }
N.m1 <- N.m1 / pmax(Nvirg.c1 + (n.c1 - nvirg.c1),1)
    }
  # M2) Grade below/above:
if (n.m2 > 0)  {
  ED.m2 <- rbind(ED[Mi2,]); virg.m2 <- which(ED.m2[,1] < 1); nvirg.m2 <- length(virg.m2)
  if (nvirg.m2 > 0)  {
K.m2 <- rbind( (Unif.w[Mi2[virg.m2],] > PI[Mi2[virg.m2],1]) + 
               (Unif.w[Mi2[virg.m2],] > CDF.w2[Mi2[virg.m2]]) )
I.m2 <- row(K.m2) + nvirg.m2*K.m2
Dsim.m2 <- matrix(ED.m2[virg.m2,][I.m2], nvirg.m2, S.supply)  >  Unif.d[Mi2[virg.m2],]
Nvirg.m2 <- colSums(Dsim.m2, na.rm=TRUE)
      }
N.m2 <- Nvirg.m2 + (n.m2 - nvirg.m2)
    }
  # C2) Grade below/above:
if (n.c2 > 0)  {
  ED.c2 <- rbind(ED[Ci2,]); virg.c2 <- which(ED.c2[,1] < 1); nvirg.c2 <- length(virg.c2)
  if (nvirg.c2 > 0)  {
K.c2 <- rbind( (Unif.w[Ci2[virg.c2],] > PI[Ci2[virg.c2],1]) + 
               (Unif.w[Ci2[virg.c2],] > CDF.w2[Ci2[virg.c2]]) )
I.c2 <- row(K.c2) + nvirg.c2*K.c2
Dsim.c2 <- matrix(ED.c2[virg.c2,][I.c2], nvirg.c2, S.supply)  >  Unif.d[Ci2[virg.c2],]
Nvirg.c2 <- colSums(Dsim.c2, na.rm=TRUE)
      }
N.m2 <- N.m2 / pmax(Nvirg.c2 + (n.c2 - nvirg.c2),1)
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(N.m1,N.m2) ) )
  }
Elam
}  #  END  Elam.2supply



### ONE SUPPLY GROUP

Elam.1supply <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)( 0 ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]
  Ci1 <- C1[[i]]
  n.m1 <- length(Mi1)
  n.c1 <- length(Ci1)
  N.m1 <- 0
  Nvirg.m1 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
N.m1 <- Nvirg.m1 + (n.m1 - nvirg.m1)
    }
  # C1) Same grade:
if (n.c1 > 0)  {
  ED.c1 <- rbind(ED[Ci1,]); virg.c1 <- which(ED.c1[,1] < 1); nvirg.c1 <- length(virg.c1)
  if (nvirg.c1 > 0)  {
K.c1 <- rbind( (Unif.w[Ci1[virg.c1],] > PI[Ci1[virg.c1],1]) + 
               (Unif.w[Ci1[virg.c1],] > CDF.w2[Ci1[virg.c1]]) )
I.c1 <- row(K.c1) + nvirg.c1*K.c1
Dsim.c1 <- matrix(ED.c1[virg.c1,][I.c1], nvirg.c1, S.supply)  >  Unif.d[Ci1[virg.c1],]
Nvirg.c1 <- colSums(Dsim.c1, na.rm=TRUE)
      }
N.m1 <- N.m1 / pmax(Nvirg.c1 + (n.c1 - nvirg.c1),1)
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(N.m1) ) )
  }
Elam
}  #  END  Elam.1supply



### SPLIT SUPPLY GROUPS

Elam.splitsup <- function(lambda,index,ED)  {
  #
  Elam <- rep( Match(lambda)(cbind(0,0) ), length(index) )
  #
for (s in 1:length(index) )  {
  i <- index[s]
  #
  Mi1 <- M1[[i]]; Mi3 <- M3[[i]]
  Ci1 <- C1[[i]]; Ci3 <- C3[[i]]
  n.m1 <- length(Mi1); n.m3 <- length(Mi3)
  n.c1 <- length(Ci1); n.c3 <- length(Ci3)
  N.m1 <- 0; N.m3 <- 0
  Nvirg.m1 <- 0; Nvirg.m3 <- 0
  #
  # M1) Same grade:
if (n.m1 > 0)  {
  ED.m1 <- rbind(ED[Mi1,]); virg.m1 <- which(ED.m1[,1] < 1); nvirg.m1 <- length(virg.m1)
  if (nvirg.m1 > 0)  {
K.m1 <- rbind( (Unif.w[Mi1[virg.m1],] > PI[Mi1[virg.m1],1]) + 
               (Unif.w[Mi1[virg.m1],] > CDF.w2[Mi1[virg.m1]]) )
I.m1 <- row(K.m1) + nvirg.m1*K.m1
Dsim.m1 <- matrix(ED.m1[virg.m1,][I.m1], nvirg.m1, S.supply)  >  Unif.d[Mi1[virg.m1],]
Nvirg.m1 <- colSums(Dsim.m1, na.rm=TRUE)
      }
N.m1 <- Nvirg.m1 + (n.m1 - nvirg.m1)
    }
  # C1) Same grade:
if (n.c1 > 0)  {
  ED.c1 <- rbind(ED[Ci1,]); virg.c1 <- which(ED.c1[,1] < 1); nvirg.c1 <- length(virg.c1)
  if (nvirg.c1 > 0)  {
K.c1 <- rbind( (Unif.w[Ci1[virg.c1],] > PI[Ci1[virg.c1],1]) + 
               (Unif.w[Ci1[virg.c1],] > CDF.w2[Ci1[virg.c1]]) )
I.c1 <- row(K.c1) + nvirg.c1*K.c1
Dsim.c1 <- matrix(ED.c1[virg.c1,][I.c1], nvirg.c1, S.supply)  >  Unif.d[Ci1[virg.c1],]
Nvirg.c1 <- colSums(Dsim.c1, na.rm=TRUE)
      }
N.m1 <- N.m1 / pmax(Nvirg.c1 + (n.c1 - nvirg.c1),1)
    }
  # M3) Grade above / two above:
if (n.m3 > 0)  {
  ED.m3 <- rbind(ED[Mi3,]); virg.m3 <- which(ED.m3[,1] < 1); nvirg.m3 <- length(virg.m3)
  if (nvirg.m3 > 0)  {
K.m3 <- rbind( (Unif.w[Mi3[virg.m3],] > PI[Mi3[virg.m3],1]) + 
               (Unif.w[Mi3[virg.m3],] > CDF.w2[Mi3[virg.m3]]) )
I.m3 <- row(K.m3) + nvirg.m3*K.m3
Dsim.m3 <- matrix(ED.m3[virg.m3,][I.m3], nvirg.m3, S.supply)  >  Unif.d[Mi3[virg.m3],]
Nvirg.m3 <- colSums(Dsim.m3, na.rm=TRUE)
      }
N.m3 <- Nvirg.m3 + (n.m3 - nvirg.m3)
    }
  # C3) Grade above / two above:
if (n.c3 > 0)  {
  ED.c3 <- rbind(ED[Ci3,]); virg.c3 <- which(ED.c3[,1] < 1); nvirg.c3 <- length(virg.c3)
  if (nvirg.c3 > 0)  {
K.c3 <- rbind( (Unif.w[Ci3[virg.c3],] > PI[Ci3[virg.c3],1]) + 
               (Unif.w[Ci3[virg.c3],] > CDF.w2[Ci3[virg.c3]]) )
I.c3 <- row(K.c3) + nvirg.c3*K.c3
Dsim.c3 <- matrix(ED.c3[virg.c3,][I.c3], nvirg.c3, S.supply)  >  Unif.d[Ci3[virg.c3],]
Nvirg.c3 <- colSums(Dsim.c3, na.rm=TRUE)
      }
N.m3 <- N.m3 / pmax(Nvirg.c3 + (n.c3 - nvirg.c3),1)
    }
  # Match function:
Elam[s] <- mean( Match(lambda)(cbind(N.m1,N.m3) ) )
  }
Elam
}  #  END  Elam.splitsup

