# Define function for simulated likelihood, and ancillary functions.



### SUPPORT FUNCTIONS

# Final likelihood function:
# (runs like.sml multiple times for auxiliary parameters)

like.final <- function(parameters)  {
  parassign(parameters)  # 0 sec
  model.solve()          # 5 sec
  like.sml(parameters)   # 47 sec  (S.supply=50)
  model.solve()          # 5 sec
  like.sml(parameters)   # 47 sec  (S.supply=50)
  like.sml(parameters)   # 47 sec  (S.supply=50)
  }

# Front-end program for two types:
# (main likelihood fn allows for three)

like.2types <- function(subset)  {
  like.final(
  c(subset[1:2], rep(subset[3],2),subset[4 ], rep(subset[5 ],2),subset[6 ],
    subset[7:8], rep(subset[9],2),subset[10], rep(subset[11],2),subset[12],
    subset[13:26],
    pi2.b,subset[27:33], pi2.g,subset[34:40])
  )
}  #  (may.10)

# Assign parameter values:

parassign <- function(parameters)  {

# Parameters: (age.b,g.b,W.b,v.b, age.g,g.g,W.g,v.g, lambdas.b,lambdas.g, pi.b,pi.g) 

# Flow payoffs:

a1.b <<- parameters[1]; a1.g <<- parameters[9]
names(a1.b) <<- "boys"; names(a1.g) <<- "girls"

g.b <<- parameters[2];  g.g <<- parameters[10]

W.b <<- parameters[3:5];  W.g <<- parameters[11:13]
names(W.b) <<- c("W.b", "Lo", "Hi"); names(W.g) <<- c("W.g", "Lo", "Hi")

# Future payoffs:

v.b <<- parameters[6:8]; v.g <<- parameters[14:16]

# (B <- 0.9)
# (d <- 0)

# Arrival rates:

l0.b9 <- parameters[17]; l0.b10 <- parameters[18]; l0.b11 <- parameters[19]; l0.b12 <- parameters[20]
l1.b <- parameters[21]; l2.b <- parameters[22]; l3.b <- parameters[23] 

l0.g9 <- parameters[24]; l0.g10 <- parameters[25]; l0.g11 <- parameters[26]; l0.g12 <- parameters[27]
l1.g <- parameters[28]; l2.g <- parameters[29]; l3.g <- parameters[30] 

lambda.b9  <<- c(l0.b9,  l1.b,l3.b)     ; lambda.g9  <<- c(l0.g9,  l1.g,l2.g,l3.g)
lambda.b10 <<- c(l0.b10, l1.b,l2.b,l3.b); lambda.g10 <<- c(l0.g10, l1.g,l2.g,l3.g)
lambda.b11 <<- c(l0.b11, l1.b,l2.b,l3.b); lambda.g11 <<- c(l0.g11, l1.g,l2.g)
lambda.b12 <<- c(l0.b12, l1.b,l2.b)     ; lambda.g12 <<- c(l0.g12, l1.g)
names(lambda.b9)[1] <<- "lambda.b"      ; names(lambda.g9)[1] <<- "lambda.g"

# Type distributions:

pi2.b <<- parameters[31:37]; pi3.b <<- parameters[38:44]
names(pi2.b) <<- c("pi2.b", "Y0.b9", "Y0.g9", indvars) 
names(pi3.b) <<- c("pi3.b", "Y0.b9", "Y0.g9", indvars) 

pi2.g <<- parameters[45:51]; pi3.g <<- parameters[52:58]
names(pi2.g) <<- c("pi2.g", "Y0.g9", "Y0.b9", indvars) 
names(pi3.g) <<- c("pi3.g", "Y0.g9", "Y0.b9", indvars) 

}  #  END parassign (5/4/10)



### LIKELIHOOD FUNCTION

like.sml <- function(parameters)  {



### A) INDIVIDUAL CONTRIBUTIONS



### 1) TYPES

PI <<- PI.0 <- matrix(1/3, n, 3)

PI.0[c(virgins.b8,virgins.bHS),] <- 
  pifun(pi2.b,pi3.b)( cbind(1,hbar.0,as.matrix(data[,indvars]))[c(virgins.b8,virgins.bHS),] )

PI.0[c(virgins.g8,virgins.gHS),] <-
  pifun(pi2.g,pi3.g)( cbind(1,hbar.0,as.matrix(data[,indvars]))[c(virgins.g8,virgins.gHS),] )

# 8th and 9th grade cohorts:

PI[c(virgins.b8,virgins.b9,virgins.g8,virgins.g9),] <<-
  PI.0[c(virgins.b8,virgins.b9,virgins.g8,virgins.g9),]

# 10th grade cohort:

h1.b <- h.b10.F94; h2.b <- psi.qtr(h1.b); h3.b <- psi.qtr(h2.b); h4.b <- psi.qtr(h3.b)
h1.g <- h.g10.F94; h2.g <- psi.qtr(h1.g); h3.g <- psi.qtr(h2.g); h4.g <- psi.qtr(h3.g)

Laux1.b <- cbind(1,h1.b,Xbar.Mb10) %*% Laux.b.F9; Laux1.b <- ifelse(Laux1.b < 0, 0, Laux1.b)
Laux2.b <- cbind(1,h2.b,Xbar.Mb10) %*% Laux.b.W9; Laux2.b <- ifelse(Laux2.b < 0, 0, Laux2.b)
Laux3.b <- cbind(1,h3.b,Xbar.Mb10) %*% Laux.b.S9; Laux3.b <- ifelse(Laux3.b < 0, 0, Laux3.b)
Laux4.b <- cbind(1,h4.b,Xbar.Mb10) %*% Laux.b.U9; Laux4.b <- ifelse(Laux4.b < 0, 0, Laux4.b)

Laux1.g <- cbind(1,h1.g,Xbar.Mg10) %*% Laux.g.F9; Laux1.g <- ifelse(Laux1.g < 0, 0, Laux1.g)
Laux2.g <- cbind(1,h2.g,Xbar.Mg10) %*% Laux.g.W9; Laux2.g <- ifelse(Laux2.g < 0, 0, Laux2.g)
Laux3.g <- cbind(1,h3.g,Xbar.Mg10) %*% Laux.g.S9; Laux3.g <- ifelse(Laux3.g < 0, 0, Laux3.g)
Laux4.g <- cbind(1,h4.g,Xbar.Mg10) %*% Laux.g.U9; Laux4.g <- ifelse(Laux4.g < 0, 0, Laux4.g)

Pvirg.b <- PI.0[virgins.b10,] * (1-Laux1.b)*(1-Laux2.b)*(1-Laux3.b)*(1-Laux4.b)
Pvirg.g <- PI.0[virgins.g10,] * (1-Laux1.g)*(1-Laux2.g)*(1-Laux3.g)*(1-Laux4.g)

PI[virgins.b10,] <<- Pvirg.b / rowSums(Pvirg.b)
PI[virgins.g10,] <<- Pvirg.g / rowSums(Pvirg.g)

# 11th grade cohort:

h1.b <- h.b11.F94; h2.b <- psi.qtr(h1.b); h3.b <- psi.qtr(h2.b); h4.b <- psi.qtr(h3.b)
  h5.b <- psi.ann(h1.b); h6.b <- psi.qtr(h5.b); h7.b <- psi.qtr(h6.b); h8.b <- psi.qtr(h7.b)
h1.g <- h.g11.F94; h2.g <- psi.qtr(h1.g); h3.g <- psi.qtr(h2.g); h4.g <- psi.qtr(h3.g)
  h5.g <- psi.ann(h1.g); h6.g <- psi.qtr(h5.g); h7.g <- psi.qtr(h6.g); h8.g <- psi.qtr(h7.g)

Laux1.b <- cbind(1,h1.b,Xbar.Mb11) %*% Laux.b.F9; Laux1.b <- ifelse(Laux1.b < 0, 0, Laux1.b)
Laux2.b <- cbind(1,h2.b,Xbar.Mb11) %*% Laux.b.W9; Laux2.b <- ifelse(Laux2.b < 0, 0, Laux2.b)
Laux3.b <- cbind(1,h3.b,Xbar.Mb11) %*% Laux.b.S9; Laux3.b <- ifelse(Laux3.b < 0, 0, Laux3.b)
Laux4.b <- cbind(1,h4.b,Xbar.Mb11) %*% Laux.b.U9; Laux4.b <- ifelse(Laux4.b < 0, 0, Laux4.b)
Laux5.b <- cbind(1,h5.b,Xbar.Mb11) %*% Laux.b.F10; Laux5.b <- ifelse(Laux5.b < 0, 0, Laux5.b)
Laux6.b <- cbind(1,h6.b,Xbar.Mb11) %*% Laux.b.W10; Laux6.b <- ifelse(Laux6.b < 0, 0, Laux6.b)
Laux7.b <- cbind(1,h7.b,Xbar.Mb11) %*% Laux.b.S10; Laux7.b <- ifelse(Laux7.b < 0, 0, Laux7.b)
Laux8.b <- cbind(1,h8.b,Xbar.Mb11) %*% Laux.b.U10; Laux8.b <- ifelse(Laux8.b < 0, 0, Laux8.b)

Laux1.g <- cbind(1,h1.g,Xbar.Mg11) %*% Laux.g.F9; Laux1.g <- ifelse(Laux1.g < 0, 0, Laux1.g)
Laux2.g <- cbind(1,h2.g,Xbar.Mg11) %*% Laux.g.W9; Laux2.g <- ifelse(Laux2.g < 0, 0, Laux2.g)
Laux3.g <- cbind(1,h3.g,Xbar.Mg11) %*% Laux.g.S9; Laux3.g <- ifelse(Laux3.g < 0, 0, Laux3.g)
Laux4.g <- cbind(1,h4.g,Xbar.Mg11) %*% Laux.g.U9; Laux4.g <- ifelse(Laux4.g < 0, 0, Laux4.g)
Laux5.g <- cbind(1,h5.g,Xbar.Mg11) %*% Laux.g.F10; Laux5.g <- ifelse(Laux5.g < 0, 0, Laux5.g)
Laux6.g <- cbind(1,h6.g,Xbar.Mg11) %*% Laux.g.W10; Laux6.g <- ifelse(Laux6.g < 0, 0, Laux6.g)
Laux7.g <- cbind(1,h7.g,Xbar.Mg11) %*% Laux.g.S10; Laux7.g <- ifelse(Laux7.g < 0, 0, Laux7.g)
Laux8.g <- cbind(1,h8.g,Xbar.Mg11) %*% Laux.g.U10; Laux8.g <- ifelse(Laux8.g < 0, 0, Laux8.g)

Pvirg.b <- PI.0[virgins.b11,] * (1-Laux1.b)*(1-Laux2.b)*(1-Laux3.b)*(1-Laux4.b)*
  (1-Laux5.b)*(1-Laux6.b)*(1-Laux7.b)*(1-Laux8.b)
Pvirg.g <- PI.0[virgins.g11,] * (1-Laux1.g)*(1-Laux2.g)*(1-Laux3.g)*(1-Laux4.g)*
  (1-Laux5.g)*(1-Laux6.g)*(1-Laux7.g)*(1-Laux8.g)

PI[virgins.b11,] <<- Pvirg.b / rowSums(Pvirg.b)
PI[virgins.g11,] <<- Pvirg.g / rowSums(Pvirg.g)

# 12th grade cohort:

h1.b <- h.b12.F94; h2.b <- psi.qtr(h1.b); h3.b <- psi.qtr(h2.b); h4.b <- psi.qtr(h3.b)
  h5.b <- psi.ann(h1.b); h6.b <- psi.qtr(h5.b); h7.b <- psi.qtr(h6.b); h8.b <- psi.qtr(h7.b)
  h9.b <- psi.ann(h5.b); h10.b <- psi.qtr(h9.b); h11.b <- psi.qtr(h10.b); h12.b <- psi.qtr(h11.b)
h1.g <- h.g12.F94; h2.g <- psi.qtr(h1.g); h3.g <- psi.qtr(h2.g); h4.g <- psi.qtr(h3.g)
  h5.g <- psi.ann(h1.g); h6.g <- psi.qtr(h5.g); h7.g <- psi.qtr(h6.g); h8.g <- psi.qtr(h7.g)
  h9.g <- psi.ann(h5.g); h10.g <- psi.qtr(h9.g); h11.g <- psi.qtr(h10.g); h12.g <- psi.qtr(h11.g)

Laux1.b <- cbind(1,h1.b,Xbar.Mb12) %*% Laux.b.F9; Laux1.b <- ifelse(Laux1.b < 0, 0, Laux1.b)
Laux2.b <- cbind(1,h2.b,Xbar.Mb12) %*% Laux.b.W9; Laux2.b <- ifelse(Laux2.b < 0, 0, Laux2.b)
Laux3.b <- cbind(1,h3.b,Xbar.Mb12) %*% Laux.b.S9; Laux3.b <- ifelse(Laux3.b < 0, 0, Laux3.b)
Laux4.b <- cbind(1,h4.b,Xbar.Mb12) %*% Laux.b.U9; Laux4.b <- ifelse(Laux4.b < 0, 0, Laux4.b)
Laux5.b <- cbind(1,h5.b,Xbar.Mb12) %*% Laux.b.F10; Laux5.b <- ifelse(Laux5.b < 0, 0, Laux5.b)
Laux6.b <- cbind(1,h6.b,Xbar.Mb12) %*% Laux.b.W10; Laux6.b <- ifelse(Laux6.b < 0, 0, Laux6.b)
Laux7.b <- cbind(1,h7.b,Xbar.Mb12) %*% Laux.b.S10; Laux7.b <- ifelse(Laux7.b < 0, 0, Laux7.b)
Laux8.b <- cbind(1,h8.b,Xbar.Mb12) %*% Laux.b.U10; Laux8.b <- ifelse(Laux8.b < 0, 0, Laux8.b)
Laux9.b <- cbind(1,h9.b,Xbar.Mb12) %*% Laux.b.F11; Laux9.b <- ifelse(Laux9.b < 0, 0, Laux9.b)
Laux10.b <- cbind(1,h10.b,Xbar.Mb12) %*% Laux.b.W11; Laux10.b <- ifelse(Laux10.b < 0, 0, Laux10.b)
Laux11.b <- cbind(1,h11.b,Xbar.Mb12) %*% Laux.b.S11; Laux11.b <- ifelse(Laux11.b < 0, 0, Laux11.b)
Laux12.b <- cbind(1,h12.b,Xbar.Mb12) %*% Laux.b.U11; Laux12.b <- ifelse(Laux12.b < 0, 0, Laux12.b)

Laux1.g <- cbind(1,h1.g,Xbar.Mg12) %*% Laux.g.F9; Laux1.g <- ifelse(Laux1.g < 0, 0, Laux1.g)
Laux2.g <- cbind(1,h2.g,Xbar.Mg12) %*% Laux.g.W9; Laux2.g <- ifelse(Laux2.g < 0, 0, Laux2.g)
Laux3.g <- cbind(1,h3.g,Xbar.Mg12) %*% Laux.g.S9; Laux3.g <- ifelse(Laux3.g < 0, 0, Laux3.g)
Laux4.g <- cbind(1,h4.g,Xbar.Mg12) %*% Laux.g.U9; Laux4.g <- ifelse(Laux4.g < 0, 0, Laux4.g)
Laux5.g <- cbind(1,h5.g,Xbar.Mg12) %*% Laux.g.F10; Laux5.g <- ifelse(Laux5.g < 0, 0, Laux5.g)
Laux6.g <- cbind(1,h6.g,Xbar.Mg12) %*% Laux.g.W10; Laux6.g <- ifelse(Laux6.g < 0, 0, Laux6.g)
Laux7.g <- cbind(1,h7.g,Xbar.Mg12) %*% Laux.g.S10; Laux7.g <- ifelse(Laux7.g < 0, 0, Laux7.g)
Laux8.g <- cbind(1,h8.g,Xbar.Mg12) %*% Laux.g.U10; Laux8.g <- ifelse(Laux8.g < 0, 0, Laux8.g)
Laux9.g <- cbind(1,h9.g,Xbar.Mg12) %*% Laux.g.F11; Laux9.g <- ifelse(Laux9.g < 0, 0, Laux9.g)
Laux10.g <- cbind(1,h10.g,Xbar.Mg12) %*% Laux.g.W11; Laux10.g <- ifelse(Laux10.g < 0, 0, Laux10.g)
Laux11.g <- cbind(1,h11.g,Xbar.Mg12) %*% Laux.g.S11; Laux11.g <- ifelse(Laux11.g < 0, 0, Laux11.g)
Laux12.g <- cbind(1,h12.g,Xbar.Mg12) %*% Laux.g.U11; Laux12.g <- ifelse(Laux12.g < 0, 0, Laux12.g)

Pvirg.b <- PI.0[virgins.b12,] * (1-Laux1.b)*(1-Laux2.b)*(1-Laux3.b)*(1-Laux4.b)*
  (1-Laux5.b)*(1-Laux6.b)*(1-Laux7.b)*(1-Laux8.b)*(1-Laux9.b)*(1-Laux10.b)*(1-Laux11.b)*(1-Laux12.b)
Pvirg.g <- PI.0[virgins.g12,] * (1-Laux1.g)*(1-Laux2.g)*(1-Laux3.g)*(1-Laux4.g)*
  (1-Laux5.g)*(1-Laux6.g)*(1-Laux7.g)*(1-Laux8.g)*(1-Laux9.g)*(1-Laux10.g)*(1-Laux11.g)*(1-Laux12.g)

PI[virgins.b12,] <<- Pvirg.b / rowSums(Pvirg.b)
PI[virgins.g12,] <<- Pvirg.g / rowSums(Pvirg.g)

# All:

CDF.w2 <<- PI[,1]+PI[,2]



### 2) SEARCH DECISIONS

# Search probabilities for virgins:

# (year one)

F.b.F94 <- rbind( 
  Vdiff.b.F9(W.b, h.b9.F94, Xbar.Mb9[vov.b9.F94,], pop.Pb9[vov.b9.F94], nosupply.b9a[vov.b9.F94,]),
  Vdiff.b.F10(W.b, h.b10.F94, Xbar.Mb10[vov.b10.F94,], pop.Pb10[vov.b10.F94], nosupply.b10a[vov.b10.F94,]),
  Vdiff.b.F11(W.b, h.b11.F94, Xbar.Mb11[vov.b11.F94,], pop.Pb11[vov.b11.F94], nosupply.b11[vov.b11.F94,]),
  Vdiff.b.F12(W.b, h.b12.F94, Xbar.Mb12[vov.b12.F94,], pop.Pb12[vov.b12.F94], nosupply.b12[vov.b12.F94,])
  )
F.g.F94 <- rbind( 
  Vdiff.g.F9(W.g, h.g9.F94, Xbar.Mg9[vov.g9.F94,], pop.Pg9[vov.g9.F94], nosupply.g9a[vov.g9.F94,]),
  Vdiff.g.F10(W.g, h.g10.F94, Xbar.Mg10[vov.g10.F94,], pop.Pg10[vov.g10.F94], nosupply.g10[vov.g10.F94,]),
  Vdiff.g.F11(W.g, h.g11.F94, Xbar.Mg11[vov.g11.F94,], pop.Pg11[vov.g11.F94], nosupply.g11[vov.g11.F94,]),
  Vdiff.g.F12(W.g, h.g12.F94, Xbar.Mg12[vov.g12.F94,], pop.Pg12[vov.g12.F94], nosupply.g12[vov.g12.F94,])
  )

F.b.W95 <- rbind( 
  Vdiff.b.W9( W.b, h.b9.W95, Xbar.Mb9[vov.b9.W95,], pop.Pb9[vov.b9.W95], nosupply.b9a[vov.b9.W95,]),
  Vdiff.b.W10(W.b, h.b10.W95, Xbar.Mb10[vov.b10.W95,], pop.Pb10[vov.b10.W95], nosupply.b10a[vov.b10.W95,]),
  Vdiff.b.W11(W.b, h.b11.W95, Xbar.Mb11[vov.b11.W95,], pop.Pb11[vov.b11.W95], nosupply.b11[vov.b11.W95,]),
  Vdiff.b.W12(W.b, h.b12.W95, Xbar.Mb12[vov.b12.W95,], pop.Pb12[vov.b12.W95], nosupply.b12[vov.b12.W95,])
  )
F.g.W95 <- rbind( 
  Vdiff.g.W9(W.g, h.g9.W95, Xbar.Mg9[vov.g9.W95,], pop.Pg9[vov.g9.W95], nosupply.g9a[vov.g9.W95,]),
  Vdiff.g.W10(W.g, h.g10.W95, Xbar.Mg10[vov.g10.W95,], pop.Pg10[vov.g10.W95], nosupply.g10[vov.g10.W95,]),
  Vdiff.g.W11(W.g, h.g11.W95, Xbar.Mg11[vov.g11.W95,], pop.Pg11[vov.g11.W95], nosupply.g11[vov.g11.W95,]),
  Vdiff.g.W12(W.g, h.g12.W95, Xbar.Mg12[vov.g12.W95,], pop.Pg12[vov.g12.W95], nosupply.g12[vov.g12.W95,])
  )

F.b.S95 <- rbind( 
  Vdiff.b.S9(W.b, h.b9.S95, Xbar.Mb9[vov.b9.S95,], pop.Pb9[vov.b9.S95], nosupply.b9a[vov.b9.S95,]),
  Vdiff.b.S10(W.b, h.b10.S95, Xbar.Mb10[vov.b10.S95,], pop.Pb10[vov.b10.S95], nosupply.b10a[vov.b10.S95,]),
  Vdiff.b.S11(W.b, h.b11.S95, Xbar.Mb11[vov.b11.S95,], pop.Pb11[vov.b11.S95], nosupply.b11[vov.b11.S95,]),
  Vdiff.b.S12(W.b, h.b12.S95, Xbar.Mb12[vov.b12.S95,], nosupply.b12[vov.b12.S95,])
  )
F.g.S95 <- rbind( 
  Vdiff.g.S9(W.g, h.g9.S95, Xbar.Mg9[vov.g9.S95,], pop.Pg9[vov.g9.S95], nosupply.g9a[vov.g9.S95,]),
  Vdiff.g.S10(W.g, h.g10.S95, Xbar.Mg10[vov.g10.S95,], pop.Pg10[vov.g10.S95], nosupply.g10[vov.g10.S95,]),
  Vdiff.g.S11(W.g, h.g11.S95, Xbar.Mg11[vov.g11.S95,], pop.Pg11[vov.g11.S95], nosupply.g11[vov.g11.S95,]),
  Vdiff.g.S12(W.g, h.g12.S95, Xbar.Mg12[vov.g12.S95,], nosupply.g12[vov.g12.S95,])
  )

F.b.F94 <- pnorm(F.b.F94); F.b.W95 <- pnorm(F.b.W95); F.b.S95 <- pnorm(F.b.S95)
F.g.F94 <- pnorm(F.g.F94); F.g.W95 <- pnorm(F.g.W95); F.g.S95 <- pnorm(F.g.S95)

# (year two)

F.b.U95 <- rbind( 
  Vdiff.b.U9(W.b, h.b9.U95, Xbar.Mb9[vov.b9.U95,], pop.Pb9[vov.b9.U95], nosupply.b9a[vov.b9.U95,]),
  Vdiff.b.U10(W.b, h.b10.U95, Xbar.Mb10[vov.b10.U95,], pop.Pb10[vov.b10.U95], nosupply.b10a[vov.b10.U95,]),
  Vdiff.b.U11(W.b, h.b11.U95, Xbar.Mb11[vov.b11.U95,], pop.Pb11[vov.b11.U95], nosupply.b11[vov.b11.U95,])
  )
F.g.U95 <- rbind( 
  Vdiff.g.U9(W.g, h.g9.U95, Xbar.Mg9[vov.g9.U95,], pop.Pg9[vov.g9.U95], nosupply.g9a[vov.g9.U95,]),
  Vdiff.g.U10(W.g, h.g10.U95, Xbar.Mg10[vov.g10.U95,], pop.Pg10[vov.g10.U95], nosupply.g10[vov.g10.U95,]),
  Vdiff.g.U11(W.g, h.g11.U95, Xbar.Mg11[vov.g11.U95,], pop.Pg11[vov.g11.U95], nosupply.g11[vov.g11.U95,])
  )

F.b.F95 <- rbind( 
  Vdiff.b.F9(W.b, h.b8.F95, Xbar.Mb8[vov.b8.F95,], pop.Pb8[vov.b8.F95], nosupply.b8[vov.b8.F95,]),
  Vdiff.b.F10(W.b, h.b9.F95, Xbar.Mb9[vov.b9.F95,], pop.Pb9[vov.b9.F95], nosupply.b9[vov.b9.F95,]),
  Vdiff.b.F11(W.b, h.b10.F95, Xbar.Mb10[vov.b10.F95,], pop.Pb10[vov.b10.F95], nosupply.b10[vov.b10.F95,]),
  Vdiff.b.F12(W.b, h.b11.F95, Xbar.Mb11[vov.b11.F95,], pop.Pb11[vov.b11.F95], nosupply.b11[vov.b11.F95,])
  )
F.g.F95 <- rbind( 
  Vdiff.g.F9(W.g, h.g8.F95, Xbar.Mg8[vov.g8.F95,], pop.Pg8[vov.g8.F95], nosupply.g8[vov.g8.F95,]),
  Vdiff.g.F10(W.g, h.g9.F95, Xbar.Mg9[vov.g9.F95,], pop.Pg9[vov.g9.F95], nosupply.g9[vov.g9.F95,]),
  Vdiff.g.F11(W.g, h.g10.F95, Xbar.Mg10[vov.g10.F95,], pop.Pg10[vov.g10.F95], nosupply.g10[vov.g10.F95,]),
  Vdiff.g.F12(W.g, h.g11.F95, Xbar.Mg11[vov.g11.F95,], pop.Pg11[vov.g11.F95], nosupply.g11[vov.g11.F95,])
  )

F.b.W96 <- rbind( 
  Vdiff.b.W9(W.b, h.b8.W96, Xbar.Mb8[vov.b8.W96,], pop.Pb8[vov.b8.W96], nosupply.b8[vov.b8.W96,]),
  Vdiff.b.W10(W.b, h.b9.W96, Xbar.Mb9[vov.b9.W96,], pop.Pb9[vov.b9.W96], nosupply.b9[vov.b9.W96,]),
  Vdiff.b.W11(W.b, h.b10.W96, Xbar.Mb10[vov.b10.W96,], pop.Pb10[vov.b10.W96], nosupply.b10[vov.b10.W96,]),
  Vdiff.b.W12(W.b, h.b11.W96, Xbar.Mb11[vov.b11.W96,], pop.Pb11[vov.b11.W96], nosupply.b11[vov.b11.W96,])
  )
F.g.W96 <- rbind( 
  Vdiff.g.W9(W.g, h.g8.W96, Xbar.Mg8[vov.g8.W96,], pop.Pg8[vov.g8.W96], nosupply.g8[vov.g8.W96,]),
  Vdiff.g.W10(W.g, h.g9.W96, Xbar.Mg9[vov.g9.W96,], pop.Pg9[vov.g9.W96], nosupply.g9[vov.g9.W96,]),
  Vdiff.g.W11(W.g, h.g10.W96, Xbar.Mg10[vov.g10.W96,], pop.Pg10[vov.g10.W96], nosupply.g10[vov.g10.W96,]),
  Vdiff.g.W12(W.g, h.g11.W96, Xbar.Mg11[vov.g11.W96,], pop.Pg11[vov.g11.W96], nosupply.g11[vov.g11.W96,])
  )

F.b.S96 <- rbind( 
  Vdiff.b.S9(W.b, h.b8.S96, Xbar.Mb8[vov.b8.S96,], pop.Pb8[vov.b8.S96], nosupply.b8[vov.b8.S96,]),
  Vdiff.b.S10(W.b, h.b9.S96, Xbar.Mb9[vov.b9.S96,], pop.Pb9[vov.b9.S96], nosupply.b9[vov.b9.S96,]),
  Vdiff.b.S11(W.b, h.b10.S96, Xbar.Mb10[vov.b10.S96,], pop.Pb10[vov.b10.S96], nosupply.b10[vov.b10.S96,]),
  Vdiff.b.S12(W.b, h.b11.S96, Xbar.Mb11[vov.b11.S96,], nosupply.b11[vov.b11.S96,])
  )
F.g.S96 <- rbind( 
  Vdiff.g.S9(W.g, h.g8.S96, Xbar.Mg8[vov.g8.S96,], pop.Pg8[vov.g8.S96], nosupply.g8[vov.g8.S96,]),
  Vdiff.g.S10(W.g, h.g9.S96, Xbar.Mg9[vov.g9.S96,], pop.Pg9[vov.g9.S96], nosupply.g9[vov.g9.S96,]),
  Vdiff.g.S11(W.g, h.g10.S96, Xbar.Mg10[vov.g10.S96,], pop.Pg10[vov.g10.S96], nosupply.g10[vov.g10.S96,]),
  Vdiff.g.S12(W.g, h.g11.S96, Xbar.Mg11[vov.g11.S96,], nosupply.g11[vov.g11.S96,])
  )

F.b.U95 <- pnorm(F.b.U95); F.b.F95 <- pnorm(F.b.F95); F.b.W96 <- pnorm(F.b.W96); F.b.S96 <- pnorm(F.b.S96)
F.g.U95 <- pnorm(F.g.U95); F.g.F95 <- pnorm(F.g.F95); F.g.W96 <- pnorm(F.g.W96); F.g.S96 <- pnorm(F.g.S96)

# Expected search decisions (virgins and non-virgins):

ED.F94 <- ED.W95 <- ED.S95 <- ED.U95 <- ED.F95 <- ED.W96 <- ED.S96 <- matrix(1, n, 3)
ED.F94[c(b8,g8),] <- ED.W95[c(b8,g8),] <- ED.S95[c(b8,g8),] <- ED.U95[c(b8,g8),] <- 0
ED.U95[c(b12,g12),] <- 0

ED.F94[c(virgins.b9[vov.b9.F94],virgins.b10[vov.b10.F94],
  virgins.b11[vov.b11.F94],virgins.b12[vov.b12.F94]), ] <- F.b.F94
ED.F94[c(virgins.g9[vov.g9.F94],virgins.g10[vov.g10.F94],
  virgins.g11[vov.g11.F94],virgins.g12[vov.g12.F94]), ] <- F.g.F94

ED.W95[c(virgins.b9[vov.b9.W95],virgins.b10[vov.b10.W95],
  virgins.b11[vov.b11.W95],virgins.b12[vov.b12.W95]), ] <- F.b.W95
ED.W95[c(virgins.g9[vov.g9.W95],virgins.g10[vov.g10.W95],
  virgins.g11[vov.g11.W95],virgins.g12[vov.g12.W95]), ] <- F.g.W95

ED.S95[c(virgins.b9[vov.b9.S95],virgins.b10[vov.b10.S95],
  virgins.b11[vov.b11.S95],virgins.b12[vov.b12.S95]), ] <- F.b.S95
ED.S95[c(virgins.g9[vov.g9.S95],virgins.g10[vov.g10.S95],
  virgins.g11[vov.g11.S95],virgins.g12[vov.g12.S95]), ] <- F.g.S95

ED.U95[c(virgins.b9[vov.b9.U95],virgins.b10[vov.b10.U95],
  virgins.b11[vov.b11.U95]), ] <- F.b.U95
ED.U95[c(virgins.g9[vov.g9.U95],virgins.g10[vov.g10.U95],
  virgins.g11[vov.g11.U95]), ] <- F.g.U95

ED.F95[c(virgins.b8[vov.b8.F95],virgins.b9[vov.b9.F95],virgins.b10[vov.b10.F95],
  virgins.b11[vov.b11.F95]), ] <- F.b.F95
ED.F95[c(virgins.g8[vov.g8.F95],virgins.g9[vov.g9.F95],virgins.g10[vov.g10.F95],
  virgins.g11[vov.g11.F95]), ] <- F.g.F95

ED.W96[c(virgins.b8[vov.b8.W96],virgins.b9[vov.b9.W96],virgins.b10[vov.b10.W96],
  virgins.b11[vov.b11.W96]), ] <- F.b.W96
ED.W96[c(virgins.g8[vov.g8.W96],virgins.g9[vov.g9.W96],virgins.g10[vov.g10.W96],
  virgins.g11[vov.g11.W96]), ] <- F.g.W96

ED.S96[c(virgins.b8[vov.b8.S96],virgins.b9[vov.b9.S96],virgins.b10[vov.b10.S96],
  virgins.b11[vov.b11.S96]), ] <- F.b.S96
ED.S96[c(virgins.g8[vov.g8.S96],virgins.g9[vov.g9.S96],virgins.g10[vov.g10.S96],
  virgins.g11[vov.g11.S96]), ] <- F.g.S96



### 3) ARRIVAL RATES

Elam.F94 <- Elam.W95 <- Elam.S95 <- Elam.U95 <- Elam.F95 <- Elam.W96 <- Elam.S96 <- rep(0, n)

# F94:

Elam.b9.F94 <- virgins.b9*0
Elam.b9.F94[!grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b9,virgins.b9[!grd9sep[virgins.b9]],ED.F94)
Elam.b9.F94[grd9sep[virgins.b9]] <- Elam.1supply(lambda.b9[1:2],virgins.b9[grd9sep[virgins.b9]],ED.F94)
Elam.b10.F94 <- virgins.b10*0
Elam.b10.F94[!grd9sep[virgins.b10]] <- Elam.3supply(lambda.b10,virgins.b10[!grd9sep[virgins.b10]],ED.F94)
Elam.b10.F94[grd9sep[virgins.b10]] <- Elam.splitsup(lambda.b10[-3],virgins.b10[grd9sep[virgins.b10]],ED.F94)
Elam.b11.F94 <- Elam.3supply(lambda.b11,virgins.b11,ED.F94)
Elam.b12.F94 <- Elam.2supply(lambda.b12,virgins.b12,ED.F94)

Elam.g9.F94 <- virgins.g9*0
Elam.g9.F94[!grd9sep[virgins.g9]] <- Elam.3supply(lambda.g9,virgins.g9[!grd9sep[virgins.g9]],ED.F94)
Elam.g9.F94[grd9sep[virgins.g9]] <- Elam.1supply(lambda.g9[1:2],virgins.g9[grd9sep[virgins.g9]],ED.F94)
Elam.g10.F94 <- Elam.3supply(lambda.g10,virgins.g10,ED.F94)
Elam.g11.F94 <- Elam.2supply(lambda.g11,virgins.g11,ED.F94)
Elam.g12.F94 <- Elam.1supply(lambda.g12,virgins.g12,ED.F94)

Elam.F94[c(virgins.b9,virgins.b10,virgins.b11,virgins.b12,
           virgins.g9,virgins.g10,virgins.g11,virgins.g12 ) ] <- 
  c(Elam.b9.F94, Elam.b10.F94, Elam.b11.F94, Elam.b12.F94,
    Elam.g9.F94, Elam.g10.F94, Elam.g11.F94, Elam.g12.F94 )

# W95:

Elam.b9.W95 <- virgins.b9*0
Elam.b9.W95[!grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b9,virgins.b9[!grd9sep[virgins.b9]],ED.W95)
Elam.b9.W95[grd9sep[virgins.b9]] <- Elam.1supply(lambda.b9[1:2],virgins.b9[grd9sep[virgins.b9]],ED.W95)
Elam.b10.W95 <- virgins.b10*0
Elam.b10.W95[!grd9sep[virgins.b10]] <- Elam.3supply(lambda.b10,virgins.b10[!grd9sep[virgins.b10]],ED.W95)
Elam.b10.W95[grd9sep[virgins.b10]] <- Elam.splitsup(lambda.b10[-3],virgins.b10[grd9sep[virgins.b10]],ED.W95)
Elam.b11.W95 <- Elam.3supply(lambda.b11,virgins.b11,ED.W95)
Elam.b12.W95 <- Elam.2supply(lambda.b12,virgins.b12,ED.W95)

Elam.g9.W95 <- virgins.g9*0
Elam.g9.W95[!grd9sep[virgins.g9]] <- Elam.3supply(lambda.g9,virgins.g9[!grd9sep[virgins.g9]],ED.W95)
Elam.g9.W95[grd9sep[virgins.g9]] <- Elam.1supply(lambda.g9[1:2],virgins.g9[grd9sep[virgins.g9]],ED.W95)
Elam.g10.W95 <- Elam.3supply(lambda.g10,virgins.g10,ED.W95)
Elam.g11.W95 <- Elam.2supply(lambda.g11,virgins.g11,ED.W95)
Elam.g12.W95 <- Elam.1supply(lambda.g12,virgins.g12,ED.W95)

Elam.W95[c(virgins.b9,virgins.b10,virgins.b11,virgins.b12,
           virgins.g9,virgins.g10,virgins.g11,virgins.g12 ) ] <- 
  c(Elam.b9.W95, Elam.b10.W95, Elam.b11.W95, Elam.b12.W95,
    Elam.g9.W95, Elam.g10.W95, Elam.g11.W95, Elam.g12.W95 )

# S95:

Elam.b9.S95 <- virgins.b9*0
Elam.b9.S95[!grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b9,virgins.b9[!grd9sep[virgins.b9]],ED.S95)
Elam.b9.S95[grd9sep[virgins.b9]] <- Elam.1supply(lambda.b9[1:2],virgins.b9[grd9sep[virgins.b9]],ED.S95)
Elam.b10.S95 <- virgins.b10*0
Elam.b10.S95[!grd9sep[virgins.b10]] <- Elam.3supply(lambda.b10,virgins.b10[!grd9sep[virgins.b10]],ED.S95)
Elam.b10.S95[grd9sep[virgins.b10]] <- Elam.splitsup(lambda.b10[-3],virgins.b10[grd9sep[virgins.b10]],ED.S95)
Elam.b11.S95 <- Elam.3supply(lambda.b11,virgins.b11,ED.S95)
Elam.b12.S95 <- Elam.2supply(lambda.b12,virgins.b12,ED.S95)

Elam.g9.S95 <- virgins.g9*0
Elam.g9.S95[!grd9sep[virgins.g9]] <- Elam.3supply(lambda.g9,virgins.g9[!grd9sep[virgins.g9]],ED.S95)
Elam.g9.S95[grd9sep[virgins.g9]] <- Elam.1supply(lambda.g9[1:2],virgins.g9[grd9sep[virgins.g9]],ED.S95)
Elam.g10.S95 <- Elam.3supply(lambda.g10,virgins.g10,ED.S95)
Elam.g11.S95 <- Elam.2supply(lambda.g11,virgins.g11,ED.S95)
Elam.g12.S95 <- Elam.1supply(lambda.g12,virgins.g12,ED.S95)

Elam.S95[c(virgins.b9,virgins.b10,virgins.b11,virgins.b12,
           virgins.g9,virgins.g10,virgins.g11,virgins.g12 ) ] <- 
  c(Elam.b9.S95, Elam.b10.S95, Elam.b11.S95, Elam.b12.S95,
    Elam.g9.S95, Elam.g10.S95, Elam.g11.S95, Elam.g12.S95 )

# U95:

Elam.b9.U95 <- virgins.b9*0
Elam.b9.U95[!grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b9,virgins.b9[!grd9sep[virgins.b9]],ED.U95)
Elam.b9.U95[grd9sep[virgins.b9]] <- Elam.1supply(lambda.b9[1:2],virgins.b9[grd9sep[virgins.b9]],ED.U95)
Elam.b10.U95 <- virgins.b10*0
Elam.b10.U95[!grd9sep[virgins.b10]] <- Elam.3supply(lambda.b10,virgins.b10[!grd9sep[virgins.b10]],ED.U95)
Elam.b10.U95[grd9sep[virgins.b10]] <- Elam.splitsup(lambda.b10[-3],virgins.b10[grd9sep[virgins.b10]],ED.U95)
Elam.b11.U95 <- Elam.3supply(lambda.b11,virgins.b11,ED.U95)

Elam.g9.U95 <- virgins.g9*0
Elam.g9.U95[!grd9sep[virgins.g9]] <- Elam.3supply(lambda.g9,virgins.g9[!grd9sep[virgins.g9]],ED.U95)
Elam.g9.U95[grd9sep[virgins.g9]] <- Elam.1supply(lambda.g9[1:2],virgins.g9[grd9sep[virgins.g9]],ED.U95)
Elam.g10.U95 <- Elam.3supply(lambda.g10,virgins.g10,ED.U95)
Elam.g11.U95 <- Elam.2supply(lambda.g11,virgins.g11,ED.U95)

Elam.U95[c(virgins.b9,virgins.b10,virgins.b11,
           virgins.g9,virgins.g10,virgins.g11 ) ] <- 
  c(Elam.b9.U95, Elam.b10.U95, Elam.b11.U95, 
    Elam.g9.U95, Elam.g10.U95, Elam.g11.U95 )

# F95:

Elam.b8.F95 <- virgins.b8*0
Elam.b8.F95[!grd9sep[virgins.b8]] <- Elam.splitsup(lambda.b9,virgins.b8[!grd9sep[virgins.b8]],ED.F95)
Elam.b8.F95[grd9sep[virgins.b8]] <- Elam.1supply(lambda.b9[1:2],virgins.b8[grd9sep[virgins.b8]],ED.F95)
Elam.b9.F95 <- virgins.b9*0
Elam.b9.F95[!grd9sep[virgins.b9]] <- Elam.3supply(lambda.b10,virgins.b9[!grd9sep[virgins.b9]],ED.F95)
Elam.b9.F95[grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b10[-3],virgins.b9[grd9sep[virgins.b9]],ED.F95)
Elam.b10.F95 <- Elam.3supply(lambda.b11,virgins.b10,ED.F95)
Elam.b11.F95 <- Elam.2supply(lambda.b12,virgins.b11,ED.F95)

Elam.g8.F95 <- virgins.g8*0
Elam.g8.F95[!grd9sep[virgins.g8]] <- Elam.3supply(lambda.g9,virgins.g8[!grd9sep[virgins.g8]],ED.F95)
Elam.g8.F95[grd9sep[virgins.g8]] <- Elam.1supply(lambda.g9[1:2],virgins.g8[grd9sep[virgins.g8]],ED.F95)
Elam.g9.F95 <-  Elam.3supply(lambda.g10,virgins.g9,ED.F95)
Elam.g10.F95 <- Elam.2supply(lambda.g11,virgins.g10,ED.F95)
Elam.g11.F95 <- Elam.1supply(lambda.g12,virgins.g11,ED.F95)

Elam.F95[c(virgins.b8,virgins.b9,virgins.b10,virgins.b11,
          virgins.g8,virgins.g9,virgins.g10,virgins.g11 ) ] <- 
  c(Elam.b8.F95, Elam.b9.F95, Elam.b10.F95, Elam.b11.F95,
    Elam.g8.F95, Elam.g9.F95, Elam.g10.F95, Elam.g11.F95 )

# W96:

Elam.b8.W96 <- virgins.b8*0
Elam.b8.W96[!grd9sep[virgins.b8]] <- Elam.splitsup(lambda.b9,virgins.b8[!grd9sep[virgins.b8]],ED.W96)
Elam.b8.W96[grd9sep[virgins.b8]] <- Elam.1supply(lambda.b9[1:2],virgins.b8[grd9sep[virgins.b8]],ED.W96)
Elam.b9.W96 <- virgins.b9*0
Elam.b9.W96[!grd9sep[virgins.b9]] <- Elam.3supply(lambda.b10,virgins.b9[!grd9sep[virgins.b9]],ED.W96)
Elam.b9.W96[grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b10[-3],virgins.b9[grd9sep[virgins.b9]],ED.W96)
Elam.b10.W96 <- Elam.3supply(lambda.b11,virgins.b10,ED.W96)
Elam.b11.W96 <- Elam.2supply(lambda.b12,virgins.b11,ED.W96)

Elam.g8.W96 <- virgins.g8*0
Elam.g8.W96[!grd9sep[virgins.g8]] <- Elam.3supply(lambda.g9,virgins.g8[!grd9sep[virgins.g8]],ED.W96)
Elam.g8.W96[grd9sep[virgins.g8]] <- Elam.1supply(lambda.g9[1:2],virgins.g8[grd9sep[virgins.g8]],ED.W96)
Elam.g9.W96 <-  Elam.3supply(lambda.g10,virgins.g9,ED.W96)
Elam.g10.W96 <- Elam.2supply(lambda.g11,virgins.g10,ED.W96)
Elam.g11.W96 <- Elam.1supply(lambda.g12,virgins.g11,ED.W96)

Elam.W96[c(virgins.b8,virgins.b9,virgins.b10,virgins.b11,
          virgins.g8,virgins.g9,virgins.g10,virgins.g11 ) ] <- 
  c(Elam.b8.W96, Elam.b9.W96, Elam.b10.W96, Elam.b11.W96,
    Elam.g8.W96, Elam.g9.W96, Elam.g10.W96, Elam.g11.W96 )

# S96:

Elam.b8.S96 <- virgins.b8*0
Elam.b8.S96[!grd9sep[virgins.b8]] <- Elam.splitsup(lambda.b9,virgins.b8[!grd9sep[virgins.b8]],ED.S96)
Elam.b8.S96[grd9sep[virgins.b8]] <- Elam.1supply(lambda.b9[1:2],virgins.b8[grd9sep[virgins.b8]],ED.S96)
Elam.b9.S96 <- virgins.b9*0
Elam.b9.S96[!grd9sep[virgins.b9]] <- Elam.3supply(lambda.b10,virgins.b9[!grd9sep[virgins.b9]],ED.S96)
Elam.b9.S96[grd9sep[virgins.b9]] <- Elam.splitsup(lambda.b10[-3],virgins.b9[grd9sep[virgins.b9]],ED.S96)
Elam.b10.S96 <- Elam.3supply(lambda.b11,virgins.b10,ED.S96)
Elam.b11.S96 <- Elam.2supply(lambda.b12,virgins.b11,ED.S96)

Elam.g8.S96 <- virgins.g8*0
Elam.g8.S96[!grd9sep[virgins.g8]] <- Elam.3supply(lambda.g9,virgins.g8[!grd9sep[virgins.g8]],ED.S96)
Elam.g8.S96[grd9sep[virgins.g8]] <- Elam.1supply(lambda.g9[1:2],virgins.g8[grd9sep[virgins.g8]],ED.S96)
Elam.g9.S96 <-  Elam.3supply(lambda.g10,virgins.g9,ED.S96)
Elam.g10.S96 <- Elam.2supply(lambda.g11,virgins.g10,ED.S96)
Elam.g11.S96 <- Elam.1supply(lambda.g12,virgins.g11,ED.S96)

Elam.S96[c(virgins.b8,virgins.b9,virgins.b10,virgins.b11,
          virgins.g8,virgins.g9,virgins.g10,virgins.g11 ) ] <- 
  c(Elam.b8.S96, Elam.b9.S96, Elam.b10.S96, Elam.b11.S96,
    Elam.g8.S96, Elam.g9.S96, Elam.g10.S96, Elam.g11.S96 )



### 4) TRANSITION PROBABILITIES

# Likelihood per period:

L.F94 <- ED.F94 * Elam.F94
L.W95 <- ED.W95 * Elam.W95
L.S95 <- ED.S95 * Elam.S95
L.U95 <- ED.U95 * Elam.U95
L.F95 <- ED.F95 * Elam.F95
L.W96 <- ED.W96 * Elam.W96
L.S96 <- ED.S96 * Elam.S96



### B) UPDATE AUXILIARY REGRESSIONS



### 1) SEARCH APPROXIMATION

# Fall:

hbar.F95 <- h.F95[ match(commid, comlist), ]; EED.F95 <- rowSums(PI*ED.F95)

Dpred.Fal(EED.F95, hbar.F95)

# Winter:

hbar.W96 <- h.W96[ match(commid, comlist), ]; EED.W96 <- rowSums(PI*ED.W96)

Dpred.Wtr(EED.W96, hbar.W96)

# Spring:

hbar.S96 <- h.S96[ match(commid, comlist), ]; EED.S96 <- rowSums(PI*ED.S96)

Dpred.Spr(EED.S96, hbar.S96) 

# Summer:

hbar.U95 <- h.U95[ match(commid, comlist), ]; EED.U95 <- rowSums(PI*ED.U95)

Dpred.Sum(EED.U95, hbar.U95)



### 2) OUTCOME PROBABILITIES FOR TYPES

# Fall:

Laux.b.F9  <<- lm( L.F95[virgins.b8[vov.b8.F95],] ~ h.b8.F95 + Xbar.Mb8[vov.b8.F95,] )$coef
Laux.b.F10 <<- lm( L.F95[virgins.b9[vov.b9.F95],] ~ h.b9.F95 + Xbar.Mb9[vov.b9.F95,] )$coef
Laux.b.F11 <<- lm( L.F95[virgins.b10[vov.b10.F95],] ~ h.b10.F95 + Xbar.Mb10[vov.b10.F95,] )$coef

Laux.g.F9  <<- lm( L.F95[virgins.g8[vov.g8.F95],] ~ h.g8.F95 + Xbar.Mg8[vov.g8.F95,] )$coef
Laux.g.F10 <<- lm( L.F95[virgins.g9[vov.g9.F95],] ~ h.g9.F95 + Xbar.Mg9[vov.g9.F95,] )$coef
Laux.g.F11 <<- lm( L.F95[virgins.g10[vov.g10.F95],] ~ h.g10.F95 + Xbar.Mg10[vov.g10.F95,] )$coef

# Winter:

Laux.b.W9  <<- lm( L.W96[virgins.b8[vov.b8.W96],] ~ h.b8.W96 + Xbar.Mb8[vov.b8.W96,] )$coef
Laux.b.W10 <<- lm( L.W96[virgins.b9[vov.b9.W96],] ~ h.b9.W96 + Xbar.Mb9[vov.b9.W96,] )$coef
Laux.b.W11 <<- lm( L.W96[virgins.b10[vov.b10.W96],] ~ h.b10.W96 + Xbar.Mb10[vov.b10.W96,] )$coef

Laux.g.W9  <<- lm( L.W96[virgins.g8[vov.g8.W96],] ~ h.g8.W96 + Xbar.Mg8[vov.g8.W96,] )$coef
Laux.g.W10 <<- lm( L.W96[virgins.g9[vov.g9.W96],] ~ h.g9.W96 + Xbar.Mg9[vov.g9.W96,] )$coef
Laux.g.W11 <<- lm( L.W96[virgins.g10[vov.g10.W96],] ~ h.g10.W96 + Xbar.Mg10[vov.g10.W96,] )$coef

# Spring:

Laux.b.S9  <<- lm( L.S96[virgins.b8[vov.b8.S96],] ~ h.b8.S96 + Xbar.Mb8[vov.b8.S96,] )$coef
Laux.b.S10 <<- lm( L.S96[virgins.b9[vov.b9.S96],] ~ h.b9.S96 + Xbar.Mb9[vov.b9.S96,] )$coef
Laux.b.S11 <<- lm( L.S96[virgins.b10[vov.b10.S96],] ~ h.b10.S96 + Xbar.Mb10[vov.b10.S96,] )$coef

Laux.g.S9  <<- lm( L.S96[virgins.g8[vov.g8.S96],] ~ h.g8.S96 + Xbar.Mg8[vov.g8.S96,] )$coef
Laux.g.S10 <<- lm( L.S96[virgins.g9[vov.g9.S96],] ~ h.g9.S96 + Xbar.Mg9[vov.g9.S96,] )$coef
Laux.g.S11 <<- lm( L.S96[virgins.g10[vov.g10.S96],] ~ h.g10.S96 + Xbar.Mg10[vov.g10.S96,] )$coef

# Summer:

Laux.b.U9  <<- lm( L.U95[virgins.b9[vov.b9.U95],] ~ h.b9.U95 + Xbar.Mb9[vov.b9.U95,] )$coef
Laux.b.U10 <<- lm( L.U95[virgins.b10[vov.b10.U95],] ~ h.b10.U95 + Xbar.Mb10[vov.b10.U95,] )$coef
Laux.b.U11 <<- lm( L.U95[virgins.b11[vov.b11.U95],] ~ h.b11.U95 + Xbar.Mb11[vov.b11.U95,] )$coef

Laux.g.U9  <<- lm( L.U95[virgins.g9[vov.g9.U95],] ~ h.g9.U95 + Xbar.Mg9[vov.g9.U95,] )$coef
Laux.g.U10 <<- lm( L.U95[virgins.g10[vov.g10.U95],] ~ h.g10.U95 + Xbar.Mg10[vov.g10.U95,] )$coef
Laux.g.U11 <<- lm( L.U95[virgins.g11[vov.g11.U95],] ~ h.g11.U95 + Xbar.Mg11[vov.g11.U95,] )$coef
        


### C) RETURN LIKELIHOOD VALUE

last.run <<- date()

# Contributions for duration to first partner:

Ltot <- c( 
  rowSums( PI[init.F94,]* L.F94[init.F94,] ),
  rowSums( PI[init.W95,]*(1-L.F94[init.W95,])* L.W95[init.W95,] ),
  rowSums( PI[init.S95,]*(1-L.F94[init.S95,])*(1-L.W95[init.S95,])* L.S95[init.S95,] ),
  rowSums( PI[init.X12,]*(1-L.F94[init.X12,])*(1-L.W95[init.X12,])*(1-L.S95[init.X12,]) ),
  rowSums( PI[init.U95,]*(1-L.F94[init.U95,])*(1-L.W95[init.U95,])*(1-L.S95[init.U95,])
          * L.U95[init.U95,] ),
  rowSums( PI[init.F95,]*(1-L.F94[init.F95,])*(1-L.W95[init.F95,])*(1-L.S95[init.F95,])
          *(1-L.U95[init.F95,])* L.F95[init.F95,] ),
  rowSums( PI[init.W96,]*(1-L.F94[init.W96,])*(1-L.W95[init.W96,])*(1-L.S95[init.W96,])
          *(1-L.U95[init.W96,])*(1-L.F95[init.W96,])* L.W96[init.W96,] ),
  rowSums( PI[init.S96,]*(1-L.F94[init.S96,])*(1-L.W95[init.S96,])*(1-L.S95[init.S96,])
          *(1-L.U95[init.S96,])*(1-L.F95[init.S96,])*(1-L.W96[init.S96,])* L.S96[init.S96,] ),
  rowSums( PI[init.XXX,]*(1-L.F94[init.XXX,])*(1-L.W95[init.XXX,])*(1-L.S95[init.XXX,])
          *(1-L.U95[init.XXX,])*(1-L.F95[init.XXX,])*(1-L.W96[init.XXX,])*(1-L.S96[init.XXX,]) )
  )

# Contributions for duration to second partner:

Larv <- 
  (1-Elam.F94[Asamp])^NVsch.1 * (1-Elam.W95[Asamp])^NVsch.2 * (1-Elam.S95[Asamp])^NVsch.3 *
  (1-Elam.U95[Asamp])^NVsch.4 * 
  (1-Elam.F95[Asamp])^NVsch.5 * (1-Elam.W96[Asamp])^NVsch.6 * (1-Elam.S96[Asamp])^NVsch.7 *
  (Elam.F94[Asamp])^two.1 * (Elam.W95[Asamp])^two.2 * (Elam.S95[Asamp])^two.3 *
  (Elam.U95[Asamp])^two.4 * 
  (Elam.F95[Asamp])^two.5 * (Elam.W96[Asamp])^two.6 * (Elam.S96[Asamp])^two.7

# Total log likelihood:

-sum( log(Ltot) ) - sum( log(Larv) )

}  #  END like.sml (10/22/09)
