# Run this code interactively to compute variance estimates.
# Different loops are needed depending on the specification of the types distribution.

# Also, this considers alternative finite differences for the numeric differentiation.



### COMPUTE VARIANCE MATRICES
#  ("run a loop" refers to the loops at the end of this program)

# With finite diff=0.01:

delta <- rep(0.01, length(param) )
# (run a loop from the end)
var.01 <- solve( t(grad) %*% grad )
cbind(param, sqrt(diag(var.01) ), param / sqrt(diag(var.01) ) )

grad -> grad.01

# With finite diff=0.001:

delta <- rep(0.001, length(param) )
# (run a loop from the end)
var.001 <- solve( t(grad) %*% grad )
cbind(param, sqrt(diag(var.001) ), param / sqrt(diag(var.001) ) )

grad -> grad.001

# With finite diff=0.0001:

delta <- rep(0.0001, length(param) )
# (run a loop from the end)
var.0001 <- solve( t(grad) %*% grad )
cbind(param, sqrt(diag(var.0001) ), param / sqrt(diag(var.0001) ) )

grad -> grad.0001

rm(grad)



### COMPARE ESTIMATES AND CREATE FINAL ESTIMATE

round(cbind(param, sqrt(diag(var.01)), sqrt(diag(var.001)), sqrt(diag(var.0001)) ),5)

round(cbind(colSums(grad.01),colSums(grad.001),colSums(grad.0001) ),2)

# Final variance estimate combines deltas (larger delta used for v(w)'s):

grad <- cbind(
  grad.001[,1:4],grad.01[,5:6], grad.001[,7:10],grad.01[,11:12],
  grad.01[,13:length(param)])

var.mix <- solve( t(grad) %*% grad )

rm(grad)

# Compare estimates again:

cbind(param, sqrt(diag(var.01)), sqrt(diag(var.mix)), sqrt(diag(var.001)) )

# Final standard errors and z-ratios:

cbind(param, sqrt(diag(var.mix) ), param / sqrt(diag(var.mix) ) )



### PARAMETER TESTS

var.test <- var.mix

# Boys arrival rate:

test <- param[17:19]

restr <- rbind(param*0, param*0, param*0)
restr[cbind(1:3,17:19) ] <- 1

stat <- t(test) %*% solve(restr %*% var.test %*% t(restr) ) %*% test

stat
1-pchisq(stat, 3)

# Girls arrival rate:

test <- param[24:26]

restr <- rbind(param*0, param*0, param*0)
restr[cbind(1:3,24:26) ] <- 1

stat <- t(test) %*% solve(restr %*% var.test %*% t(restr) ) %*% test

stat
1-pchisq(stat, 3)

# Boys omega-low = girls omega-low:

test <- param[3] - param[9]

restr <- rbind(param*0)
restr[1,c(3,9)] <- c(1,-1)

stat <- t(test) %*% solve(restr %*% var.test %*% t(restr) ) %*% test

stat
1-pchisq(stat, 1)

# Boys omega-high = girls omega-high:

test <- param[4] - param[10]

restr <- rbind(param*0)
restr[1,c(4,10)] <- c(1,-1)

stat <- t(test) %*% solve(restr %*% var.test %*% t(restr) ) %*% test

stat
1-pchisq(stat, 1)

# Clean up:

rm(var.test)



### LOOPS TO COMPUTE GRADIENTS
# These are used with the commands in the first section.
#  (which one to use depends on the model)

###

# A) Individual characteristics (x) in types dist
# (either matching technology)

# Preliminaries:

param <- results.new$par

base <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:33], pi2.g,param[34:40])
)

grad  <- matrix( as.numeric(NA), length(base), length(param) )

# Loop over parameters:

for (i in 1:length(param) )  {
  orig <- param[i]
  param[i] <- param[i] + delta[i]
  newval <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:33], pi2.g,param[34:40])
  )
  grad[,i] <- (newval - base)/delta[i]
  param[i] <- orig
  print(c(i, sum(grad[,i]) ), 3)
  }

###

# B) No individual x's in types dist
# (main matching technology)

# Preliminaries:

param <- results.noxes$par

like.noxes(param)
results.noxes$val

base <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:29],rep(0,4), pi2.g,param[30:32],rep(0,4) )
  )

grad  <- matrix( as.numeric(NA), length(base), length(param) )

# Loop over parameters:

for (i in 1:length(param) )  {
  orig <- param[i]
  param[i] <- param[i] + delta[i]
  newval <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:29],rep(0,4), pi2.g,param[30:32],rep(0,4) )
  )
  grad[,i] <- (newval - base)/delta[i]
  param[i] <- orig
  print(c(i, sum(grad[,i]) ), 3)
  }

###

# C) Group means (x-bar) in types dist
# (main matching technology)

# Preliminaries:

param <- results.xbars$par

like.xbars(param)
results.xbars$val

base <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:37], pi2.g,param[38:48])
  )

grad  <- matrix( as.numeric(NA), length(base), length(param) )

# Loop over parameters:

for (i in 1:length(param) )  {
  orig <- param[i]
  param[i] <- param[i] + delta[i]
  newval <- like.var(
  c(param[1:2], rep(param[3],2),param[4 ], rep(param[5 ],2),param[6 ],
    param[7:8], rep(param[9],2),param[10], rep(param[11],2),param[12],
    param[13:26],
    pi2.b,param[27:37], pi2.g,param[38:48])
  )
  grad[,i] <- (newval - base)/delta[i]
  param[i] <- orig
  print(c(i, sum(grad[,i]) ), 3)
  }
