# Creates a table of correlations between individual virginity status
#  and the nonvirginity rates of each gender-grade group at school.



### SETUP

load("analyticfile.RData")

attach(data)



### WITHIN-SCHOOL CORRELATIONS:

# Nonvirginity rates for each gender-grade group, in the last period:

h.end <- as.matrix( h.all[h.all$t==7,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )

# Correlations between individual virginity status and each gender-grade group:

temp.cor <- matrix(0,8,8)

cor( h.end[match(commid[b8], comlist),], nonvirg_7[b8] ) -> temp.cor[1,]
cor( h.end[match(commid[b9], comlist),], nonvirg_7[b9] ) -> temp.cor[2,]
cor( h.end[match(commid[b10], comlist),], nonvirg_7[b10] ) -> temp.cor[3,]
cor( h.end[match(commid[b11], comlist),], nonvirg_7[b11] ) -> temp.cor[4,]

cor( h.end[match(commid[g8], comlist),], nonvirg_7[g8] ) -> temp.cor[5,]
cor( h.end[match(commid[g9], comlist),], nonvirg_7[g9] ) -> temp.cor[6,]
cor( h.end[match(commid[g10], comlist),], nonvirg_7[g10] ) -> temp.cor[7,]
cor( h.end[match(commid[g11], comlist),], nonvirg_7[g11] ) -> temp.cor[8,]

# Adjust nonvirginity rate in own gender-grade group:
# (need to exclude individual from his/her own group's rate)

# (boys)

temp.peer <- (pop_P[b8] * h.end[match(commid[b8], comlist),"hbar_b9"] - nonvirg_7[b8]) / (pop_P[b8]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[b8] ) -> temp.cor[1,1]

temp.peer <- (pop_P[b9] * h.end[match(commid[b9], comlist),"hbar_b10"] - nonvirg_7[b9]) / (pop_P[b9]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[b9] ) -> temp.cor[2,2]

temp.peer <- (pop_P[b10] * h.end[match(commid[b10], comlist),"hbar_b11"] - nonvirg_7[b10]) / (pop_P[b10]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[b10] ) -> temp.cor[3,3]

temp.peer <- (pop_P[b11] * h.end[match(commid[b11], comlist),"hbar_b12"] - nonvirg_7[b11]) / (pop_P[b11]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[b11] ) -> temp.cor[4,4]

# (girls)

temp.peer <- (pop_P[g8] * h.end[match(commid[g8], comlist),"hbar_g9"] - nonvirg_7[g8]) / (pop_P[g8]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[g8] ) -> temp.cor[5,5]

temp.peer <- (pop_P[g9] * h.end[match(commid[g9], comlist),"hbar_g10"] - nonvirg_7[g9]) / (pop_P[g9]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[g9] ) -> temp.cor[6,6]

temp.peer <- (pop_P[g10] * h.end[match(commid[g10], comlist),"hbar_g11"] - nonvirg_7[g10]) / (pop_P[g10]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[g10] ) -> temp.cor[7,7]

temp.peer <- (pop_P[g11] * h.end[match(commid[g11], comlist),"hbar_g12"] - nonvirg_7[g11]) / (pop_P[g11]-1)
temp.peer <- ifelse(is.na(temp.peer), 0, temp.peer)

  cor( temp.peer, nonvirg_7[g11] ) -> temp.cor[8,8]

# Results:

round(temp.cor,3)

