# Prepare data for estimation of the model in R.



### LOAD ANALYTIC FILE

library(foreign)
data <- read.dta("dynamic_R.dta")

# Replace categorical variable for parental education:
# (becomes binary indicator for 4-year college degree)

data[,"paredu"] <- data$paredu >= 3; mode(data[,"paredu"]) <- "numeric"

# Format dummy variable for school with 9th grade in separate location

mode(data[,"grd9sep"]) <- "logical"

attach(data)



### BASIC IDENTIFIERS

# Covariate names:

indvars <- c("black", "younger", "only", "paredu") 

# Sample size and samples:

n <- nrow(data)

boys <- which(bio_sex==1); girls <- which(bio_sex==2)

n.b <- length(boys); n.g <- length(girls)

# Cohort x gender groups:

b7 <- which(cohort==7 & bio_sex==1); g7 <- which(cohort==7 & bio_sex==2)  
b8 <- which(cohort==8 & bio_sex==1); g8 <- which(cohort==8 & bio_sex==2)  
b9 <- which(cohort==9 & bio_sex==1); g9 <- which(cohort==9 & bio_sex==2)
b10 <- which(cohort==10 & bio_sex==1); g10 <- which(cohort==10 & bio_sex==2)
b11 <- which(cohort==11 & bio_sex==1); g11 <- which(cohort==11 & bio_sex==2)
b12 <- which(cohort==12 & bio_sex==1); g12 <- which(cohort==12 & bio_sex==2)

# Peer, supply, and competitor groups:
# (indicate positions in vector of nonvirginity rates)

p.b9 <- 1; p.b10 <- 2; p.b11 <- 3; p.b12 <- 4; 
p.g9 <- 5; p.g10 <- 6; p.g11 <- 7; p.g12 <- 8

m.b9 <- c(5,0,6); m.b10 <- c(6,5,7); m.b11 <- c(7,6,8); m.b12 <- c(8,7)
m.g9 <- c(1,2,3); m.g10 <- c(2,3,4); m.g11 <- c(3,4); m.g12 <- c(4)     

c.b9 <- c(1,0,2); c.b10 <- c(2,1,3); c.b11 <- c(3,2,4); c.b12 <- c(4,3)
c.g9 <- c(5,6,7); c.g10 <- c(6,7,8); c.g11 <- c(7,8); c.g12 <- c(8)

# Identify initial virgins:

virgins     <- which(nonvirg_0 == 0)

# By gender:

virgins.b   <- which(nonvirg_0 == 0 & bio_sex == 1)
virgins.g   <- which(nonvirg_0 == 0 & bio_sex == 2)

# By gender and grade:

virgins.b7  <- which(nonvirg_7 == 0 & cohort == 7  & bio_sex == 1)
virgins.b8  <- which(nonvirg_4 == 0 & cohort == 8  & bio_sex == 1)
virgins.b9  <- which(nonvirg_0 == 0 & cohort == 9  & bio_sex == 1)
virgins.b10 <- which(nonvirg_0 == 0 & cohort == 10 & bio_sex == 1)
virgins.b11 <- which(nonvirg_0 == 0 & cohort == 11 & bio_sex == 1)
virgins.b12 <- which(nonvirg_0 == 0 & cohort == 12 & bio_sex == 1)
virgins.bHS <- which(nonvirg_0 == 0 & cohort >= 9  & bio_sex == 1)

virgins.g7  <- which(nonvirg_7 == 0 & cohort == 7  & bio_sex == 2)
virgins.g8  <- which(nonvirg_4 == 0 & cohort == 8  & bio_sex == 2)
virgins.g9  <- which(nonvirg_0 == 0 & cohort == 9  & bio_sex == 2)
virgins.g10 <- which(nonvirg_0 == 0 & cohort == 10 & bio_sex == 2)
virgins.g11 <- which(nonvirg_0 == 0 & cohort == 11 & bio_sex == 2)
virgins.g12 <- which(nonvirg_0 == 0 & cohort == 12 & bio_sex == 2)
virgins.gHS <- which(nonvirg_0 == 0 & cohort >= 9  & bio_sex == 2)



### SUPPLY GROUP MEMBERS

# Storage lists:
# ("M" is for "market", groups 1, 2, 3)

M1 <- as.list(1:nrow(data))
M2 <- as.list(1:nrow(data))
M3 <- as.list(1:nrow(data))

# Loops to populate storage:

for (i in boys)  {
  M1[[i]] <- which(commid==commid[i] & cohort==cohort[i] &  bio_sex==2)
  M2[[i]] <- which(commid==commid[i] & cohort==(cohort[i]-1) &  bio_sex==2)
  M3[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+1) &  bio_sex==2)
  }

for (i in girls)  {
  M1[[i]] <- which(commid==commid[i] & cohort==cohort[i] &  bio_sex==1)
  M2[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+1) &  bio_sex==1)
  M3[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+2) &  bio_sex==1)
  }



### COMPETITOR GROUP MEMBERS

# Storage lists:
# ("C" is for "competitors", groups 1, 2, 3)

C1 <- as.list(1:nrow(data))
C2 <- as.list(1:nrow(data))
C3 <- as.list(1:nrow(data))

# Loops to populate storage:

for (i in boys)  {
  C1[[i]] <- which(commid==commid[i] & cohort==cohort[i] &  bio_sex==1)
  C2[[i]] <- which(commid==commid[i] & cohort==(cohort[i]-1) &  bio_sex==1)
  C3[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+1) &  bio_sex==1)
  }

for (i in girls)  {
  C1[[i]] <- which(commid==commid[i] & cohort==cohort[i] &  bio_sex==2)
  C2[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+1) &  bio_sex==2)
  C3[[i]] <- which(commid==commid[i] & cohort==(cohort[i]+2) &  bio_sex==2)
  }



### PEER GROUP SIZES AND MEAN X'S

# Peer group population:
# (separate vectors for each gender-grade cohort of virgins)

pop.Pb7 <- pop_P[virgins.b7]; pop.Pg7 <- pop_P[virgins.g7]
pop.Pb8 <- pop_P[virgins.b8]; pop.Pg8 <- pop_P[virgins.g8]
pop.Pb9 <- pop_P[virgins.b9]; pop.Pg9 <- pop_P[virgins.g9]
pop.Pb10 <- pop_P[virgins.b10]; pop.Pg10 <- pop_P[virgins.g10]
pop.Pb11 <- pop_P[virgins.b11]; pop.Pg11 <- pop_P[virgins.g11]
pop.Pb12 <- pop_P[virgins.b12]; pop.Pg12 <- pop_P[virgins.g12]

# Function to compute peer mean characteristics (-i):

means.j <- function(X) {
  if (nrow(X) > 1)  {
  Y <- sapply(1:nrow(X), function (i) colMeans(X[-i,]) )
  t(Y)
    }
  }

# Matrix of peer mean characteristics:

Xbar.pj <- as.matrix( data[,indvars] )*0

# Loop to populate the matrix of peer means:

for (com in levels(as.factor(commid)) )  {  for (coh in 7:12)  {  for (gen in 1:2)  {
  X.j <- data[commid==com & cohort==coh & bio_sex==gen, indvars]
  if ( nrow(X.j) > 1 )  {
  Xbar.pj[commid==com & cohort==coh & bio_sex==gen, ] <- means.j( X.j )
    }
  } } } 



### SUPPLY GROUP SIZES AND MEAN X'S

# Storage for supply group population:
# (separate vectors for each gender-grade cohort of virgins)

pop.Mb7 <- matrix(0, length(virgins.b7), 3); pop.Mg7 <- matrix(0, length(virgins.g7), 3)
pop.Mb8 <- matrix(0, length(virgins.b8), 3); pop.Mg8 <- matrix(0, length(virgins.g8), 3)
pop.Mb9 <- matrix(0, length(virgins.b9), 3); pop.Mg9 <- matrix(0, length(virgins.g9), 3)
pop.Mb10 <- matrix(0, length(virgins.b10), 3); pop.Mg10 <- matrix(0, length(virgins.g10), 3)
pop.Mb11 <- matrix(0, length(virgins.b11), 3); pop.Mg11 <- matrix(0, length(virgins.g11), 3)
pop.Mb12 <- matrix(0, length(virgins.b12), 3); pop.Mg12 <- matrix(0, length(virgins.g12), 3)

# Storage for supply group mean characteristics, and no supply:

Xbar.Mb7 <- matrix(0,length(pop.Pb7),length(indvars)); Xbar.Mg7 <- matrix(0,length(pop.Pg7),length(indvars)) 
Xbar.Mb8 <- matrix(0,length(pop.Pb8),length(indvars)); Xbar.Mg8 <- matrix(0,length(pop.Pg8),length(indvars)) 
Xbar.Mb9 <- matrix(0,length(pop.Pb9),length(indvars)); Xbar.Mg9 <- matrix(0,length(pop.Pg9),length(indvars)) 
Xbar.Mb10 <- matrix(0,length(pop.Pb10),length(indvars)); Xbar.Mg10 <- matrix(0,length(pop.Pg10),length(indvars)) 
Xbar.Mb11 <- matrix(0,length(pop.Pb11),length(indvars)); Xbar.Mg11 <- matrix(0,length(pop.Pg11),length(indvars)) 
Xbar.Mb12 <- matrix(0,length(pop.Pb12),length(indvars)); Xbar.Mg12 <- matrix(0,length(pop.Pg12),length(indvars)) 

# Loop to populate these objects:
# (done separately for each cohort b/c potentially different supply groups)

# (7th grade cohort)

for (s in 1:length(virgins.b7) )  {
  #
pop.Mb7[s,] <- c( length(M1[[ virgins.b7[s] ]]), length(M2[[ virgins.b7[s] ]]), 
  length(M3[[ virgins.b7[s] ]]) )
  #
  if (sum(pop.Mb7[s,]) > 0)  {
  #
Xbar.Mb7[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b7[s] ]], indvars], data[M2[[ virgins.b7[s] ]], indvars], 
    data[M3[[ virgins.b7[s] ]], indvars]) )
    }
  }

for (s in 1:length(virgins.g7) )  {
  #
pop.Mg7[s,] <- c(length(M1[[ virgins.g7[s] ]]), length(M2[[ virgins.g7[s] ]]),
  length(M3[[ virgins.g7[s] ]]) )
  #
  if (sum(pop.Mg7[s,]) > 0)  {
  #
Xbar.Mg7[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g7[s] ]], indvars], data[M2[[ virgins.g7[s] ]], indvars], 
    data[M3[[ virgins.g7[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b7 <- pop.Mb7[,2:3]==0; mode(nosupply.b7) <- "numeric"
nosupply.g7 <- pop.Mg7[,2:3]==0; mode(nosupply.g7) <- "numeric"

colSums(nosupply.b7)
colSums(nosupply.g7)

# (8th grade cohort)

for (s in 1:length(virgins.b8) )  {
  #
pop.Mb8[s,] <- c( length(M1[[ virgins.b8[s] ]]), length(M2[[ virgins.b8[s] ]]), 
  length(M3[[ virgins.b8[s] ]]) )
  #
  if (sum(pop.Mb8[s,]) > 0)  {
  #
Xbar.Mb8[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b8[s] ]], indvars], data[M2[[ virgins.b8[s] ]], indvars], 
    data[M3[[ virgins.b8[s] ]], indvars]) )
    }
  }

for (s in 1:length(virgins.g8) )  {
  #
pop.Mg8[s,] <- c(length(M1[[ virgins.g8[s] ]]), length(M2[[ virgins.g8[s] ]]),
  length(M3[[ virgins.g8[s] ]]) )
  #
  if (sum(pop.Mg8[s,]) > 0)  {
  #
Xbar.Mg8[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g8[s] ]], indvars], data[M2[[ virgins.g8[s] ]], indvars], 
    data[M3[[ virgins.g8[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b8 <- pop.Mb8[,2:3]==0; mode(nosupply.b8) <- "numeric"
nosupply.g8 <- pop.Mg8[,2:3]==0; mode(nosupply.g8) <- "numeric"

colSums(nosupply.b8)
colSums(nosupply.g8)

# Adjust "no supply" indicator for schools where 9th grade in separate location:
# (cohort only used in year 2, when in 9th grade; no supply from older grades)

nosupply.b8[grd9sep[virgins.b8],2] <- 1
nosupply.g8[grd9sep[virgins.g8],1:2] <- 1

# (9th grade cohort)

for (s in 1:length(virgins.b9) )  {
  #
pop.Mb9[s,] <- c( length(M1[[ virgins.b9[s] ]]), length(M2[[ virgins.b9[s] ]]), 
  length(M3[[ virgins.b9[s] ]]) )
  #
  if (sum(pop.Mb9[s,]) > 0)  {
  #
Xbar.Mb9[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b9[s] ]], indvars], data[M2[[ virgins.b9[s] ]], indvars], 
    data[M3[[ virgins.b9[s] ]], indvars]) )
    }
  }

for (s in 1:1:length(virgins.g9) )  {
  #
pop.Mg9[s,] <- c(length(M1[[ virgins.g9[s] ]]), length(M2[[ virgins.g9[s] ]]),
  length(M3[[ virgins.g9[s] ]]) )
  #
  if (sum(pop.Mg9[s,]) > 0)  {
  #
Xbar.Mg9[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g9[s] ]], indvars], data[M2[[ virgins.g9[s] ]], indvars], 
    data[M3[[ virgins.g9[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b9 <- pop.Mb9[,2:3]==0; mode(nosupply.b9) <- "numeric"
nosupply.g9 <- pop.Mg9[,2:3]==0; mode(nosupply.g9) <- "numeric"

colSums(nosupply.b9)
colSums(nosupply.g9)

# Adjust "no supply" indicator for schools where 9th grade in separate location:
# (in year 1, no supply from older grades; in years 1 & 2, boys have no supply from younger grade)

nosupply.b9a <- nosupply.b9; nosupply.g9a <- nosupply.g9

nosupply.b9a[grd9sep[virgins.b9],2] <- 1
nosupply.g9a[grd9sep[virgins.g9],1:2] <- 1

nosupply.b9[grd9sep[virgins.b9],1] <- 1

# (10th grade cohort)

for (s in 1:length(virgins.b10) )  {
  #
pop.Mb10[s,] <- c( length(M1[[ virgins.b10[s] ]]), length(M2[[ virgins.b10[s] ]]), 
  length(M3[[ virgins.b10[s] ]]) )
  #
  if (sum(pop.Mb10[s,]) > 0)  {
  #
Xbar.Mb10[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b10[s] ]], indvars], data[M2[[ virgins.b10[s] ]], indvars], 
    data[M3[[ virgins.b10[s] ]], indvars]) )
    }
  }

for (s in 1:1:length(virgins.g10) )  {
  #
pop.Mg10[s,] <- c(length(M1[[ virgins.g10[s] ]]), length(M2[[ virgins.g10[s] ]]),
  length(M3[[ virgins.g10[s] ]]) )
  #
  if (sum(pop.Mg10[s,]) > 0)  {
  #
Xbar.Mg10[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g10[s] ]], indvars], data[M2[[ virgins.g10[s] ]], indvars], 
    data[M3[[ virgins.g10[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b10 <- pop.Mb10[,2:3]==0; mode(nosupply.b10) <- "numeric"
nosupply.g10 <- pop.Mg10[,2:3]==0; mode(nosupply.g10) <- "numeric"

colSums(nosupply.b10)
colSums(nosupply.g10)

# Adjust "no supply" indicator for schools where 9th grade in separate location:
# (in year 1, boys have no supply from younger grade)

nosupply.b10a <- nosupply.b10
nosupply.b10a[grd9sep[virgins.b10],1] <- 1

# (11th grade cohort)

for (s in 1:length(virgins.b11) )  {
  #
pop.Mb11[s,] <- c( length(M1[[ virgins.b11[s] ]]), length(M2[[ virgins.b11[s] ]]), 
  length(M3[[ virgins.b11[s] ]]) )
  #
  if (sum(pop.Mb11[s,]) > 0)  {
  #
Xbar.Mb11[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b11[s] ]], indvars], data[M2[[ virgins.b11[s] ]], indvars], 
    data[M3[[ virgins.b11[s] ]], indvars]) )
    }
  }

for (s in 1:1:length(virgins.g11) )  {
  #
pop.Mg11[s,] <- c(length(M1[[ virgins.g11[s] ]]), length(M2[[ virgins.g11[s] ]]),
  length(M3[[ virgins.g11[s] ]]) )
  #
  if (sum(pop.Mg11[s,]) > 0)  {
  #
Xbar.Mg11[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g11[s] ]], indvars], data[M2[[ virgins.g11[s] ]], indvars], 
    data[M3[[ virgins.g11[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b11 <- pop.Mb11[,2:3]==0; mode(nosupply.b11) <- "numeric"
nosupply.g11 <- pop.Mg11[,2:3]==0; mode(nosupply.g11) <- "numeric"

colSums(nosupply.b11)
colSums(nosupply.g11)

# (12th grade cohort)

for (s in 1:length(virgins.b12) )  {
  #
pop.Mb12[s,] <- c( length(M1[[ virgins.b12[s] ]]), length(M2[[ virgins.b12[s] ]]), 
  length(M3[[ virgins.b12[s] ]]) )
  #
  if (sum(pop.Mb12[s,]) > 0)  {
  #
Xbar.Mb12[s,] <- colMeans( 
  rbind(data[M1[[ virgins.b12[s] ]], indvars], data[M2[[ virgins.b12[s] ]], indvars], 
    data[M3[[ virgins.b12[s] ]], indvars]) )
    }
  }

for (s in 1:1:length(virgins.g12) )  {
  #
pop.Mg12[s,] <- c(length(M1[[ virgins.g12[s] ]]), length(M2[[ virgins.g12[s] ]]),
  length(M3[[ virgins.g12[s] ]]) )
  #
  if (sum(pop.Mg12[s,]) > 0)  {
  #
Xbar.Mg12[s,] <- colMeans( 
  rbind(data[M1[[ virgins.g12[s] ]], indvars], data[M2[[ virgins.g12[s] ]], indvars], 
    data[M3[[ virgins.g12[s] ]], indvars]) )
    }
  }

# Indicator for no supply from other grades:

nosupply.b12 <- pop.Mb12[,2:3]==0; mode(nosupply.b12) <- "numeric"
nosupply.g12 <- pop.Mg12[,2:3]==0; mode(nosupply.g12) <- "numeric"

colSums(nosupply.b12)
colSums(nosupply.g12)



### MEAN X'S FOR COMBINED PEER AND SUPPLY GROUP
#   (uses same-grade supply group)

Xbar.PM <- Xbar.pj*NA

Xbar.PM[virgins.b8 ,] <- (Xbar.pj[virgins.b8 ,] + Xbar.Mb8 )/2
Xbar.PM[virgins.b9 ,] <- (Xbar.pj[virgins.b9 ,] + Xbar.Mb9 )/2
Xbar.PM[virgins.b10,] <- (Xbar.pj[virgins.b10,] + Xbar.Mb10)/2
Xbar.PM[virgins.b11,] <- (Xbar.pj[virgins.b11,] + Xbar.Mb11)/2
Xbar.PM[virgins.b12,] <- (Xbar.pj[virgins.b12,] + Xbar.Mb12)/2

Xbar.PM[virgins.g8 ,] <- (Xbar.pj[virgins.g8 ,] + Xbar.Mg8 )/2
Xbar.PM[virgins.g9 ,] <- (Xbar.pj[virgins.g9 ,] + Xbar.Mg9 )/2
Xbar.PM[virgins.g10,] <- (Xbar.pj[virgins.g10,] + Xbar.Mg10)/2
Xbar.PM[virgins.g11,] <- (Xbar.pj[virgins.g11,] + Xbar.Mg11)/2
Xbar.PM[virgins.g12,] <- (Xbar.pj[virgins.g12,] + Xbar.Mg12)/2



### INDIVIDUAL VIRGINITY STATUS OVER TIME
#   (identifies survivors and exits in each period)

# Remaining virgins (survivors) per period:
# ("vov" = "virgins of initial virgins")

# (boys)

 vov.b9.F94 <- which(nonvirg_0[virgins.b9 ] == 0)
vov.b10.F94 <- which(nonvirg_0[virgins.b10] == 0)
vov.b11.F94 <- which(nonvirg_0[virgins.b11] == 0)
vov.b12.F94 <- which(nonvirg_0[virgins.b12] == 0)

 vov.b9.W95 <- which(nonvirg_1[virgins.b9 ] == 0)
vov.b10.W95 <- which(nonvirg_1[virgins.b10] == 0)
vov.b11.W95 <- which(nonvirg_1[virgins.b11] == 0)
vov.b12.W95 <- which(nonvirg_1[virgins.b12] == 0)

 vov.b9.S95 <- which(nonvirg_2[virgins.b9 ] == 0)
vov.b10.S95 <- which(nonvirg_2[virgins.b10] == 0)
vov.b11.S95 <- which(nonvirg_2[virgins.b11] == 0)
vov.b12.S95 <- which(nonvirg_2[virgins.b12] == 0)

 vov.b9.U95 <- which(nonvirg_3[virgins.b9 ] == 0)
vov.b10.U95 <- which(nonvirg_3[virgins.b10] == 0)
vov.b11.U95 <- which(nonvirg_3[virgins.b11] == 0)

 vov.b8.F95 <- which(nonvirg_4[virgins.b8 ] == 0)
 vov.b9.F95 <- which(nonvirg_4[virgins.b9 ] == 0)
vov.b10.F95 <- which(nonvirg_4[virgins.b10] == 0)
vov.b11.F95 <- which(nonvirg_4[virgins.b11] == 0)

 vov.b8.W96 <- which(nonvirg_5[virgins.b8 ] == 0)
 vov.b9.W96 <- which(nonvirg_5[virgins.b9 ] == 0)
vov.b10.W96 <- which(nonvirg_5[virgins.b10] == 0)
vov.b11.W96 <- which(nonvirg_5[virgins.b11] == 0)

 vov.b8.S96 <- which(nonvirg_6[virgins.b8 ] == 0)
 vov.b9.S96 <- which(nonvirg_6[virgins.b9 ] == 0)
vov.b10.S96 <- which(nonvirg_6[virgins.b10] == 0)
vov.b11.S96 <- which(nonvirg_6[virgins.b11] == 0)

# (girls)

 vov.g9.F94 <- which(nonvirg_0[virgins.g9 ] == 0)
vov.g10.F94 <- which(nonvirg_0[virgins.g10] == 0)
vov.g11.F94 <- which(nonvirg_0[virgins.g11] == 0)
vov.g12.F94 <- which(nonvirg_0[virgins.g12] == 0)

 vov.g9.W95 <- which(nonvirg_1[virgins.g9 ] == 0)
vov.g10.W95 <- which(nonvirg_1[virgins.g10] == 0)
vov.g11.W95 <- which(nonvirg_1[virgins.g11] == 0)
vov.g12.W95 <- which(nonvirg_1[virgins.g12] == 0)

 vov.g9.S95 <- which(nonvirg_2[virgins.g9 ] == 0)
vov.g10.S95 <- which(nonvirg_2[virgins.g10] == 0)
vov.g11.S95 <- which(nonvirg_2[virgins.g11] == 0)
vov.g12.S95 <- which(nonvirg_2[virgins.g12] == 0)

 vov.g9.U95 <- which(nonvirg_3[virgins.g9 ] == 0)
vov.g10.U95 <- which(nonvirg_3[virgins.g10] == 0)
vov.g11.U95 <- which(nonvirg_3[virgins.g11] == 0)

 vov.g8.F95 <- which(nonvirg_4[virgins.g8 ] == 0)
 vov.g9.F95 <- which(nonvirg_4[virgins.g9 ] == 0)
vov.g10.F95 <- which(nonvirg_4[virgins.g10] == 0)
vov.g11.F95 <- which(nonvirg_4[virgins.g11] == 0)

 vov.g8.W96 <- which(nonvirg_5[virgins.g8 ] == 0)
 vov.g9.W96 <- which(nonvirg_5[virgins.g9 ] == 0)
vov.g10.W96 <- which(nonvirg_5[virgins.g10] == 0)
vov.g11.W96 <- which(nonvirg_5[virgins.g11] == 0)

 vov.g8.S96 <- which(nonvirg_6[virgins.g8 ] == 0)
 vov.g9.S96 <- which(nonvirg_6[virgins.g9 ] == 0)
vov.g10.S96 <- which(nonvirg_6[virgins.g10] == 0)
vov.g11.S96 <- which(nonvirg_6[virgins.g11] == 0)

# Observed exits:
# ("init" = "initiate")

init.F94 <- which(nonvirg_0==0 & nonvirg_1==1 & cohort>=9 & cohort<=12)
init.W95 <- which(nonvirg_1==0 & nonvirg_2==1 & cohort>=9 & cohort<=12)
init.S95 <- which(nonvirg_2==0 & nonvirg_3==1 & cohort>=9 & cohort<=12)
init.U95 <- which(nonvirg_3==0 & nonvirg_4==1 & cohort>=9 & cohort<=11)
init.F95 <- which(nonvirg_4==0 & nonvirg_5==1 & cohort>=8 & cohort<=11)
init.W96 <- which(nonvirg_5==0 & nonvirg_6==1 & cohort>=8 & cohort<=11)
init.S96 <- which(nonvirg_6==0 & nonvirg_7==1 & cohort>=8 & cohort<=11)

# Censored durations:

init.XXX <- which(nonvirg_7==0                & cohort>=8 & cohort<=11)
init.X12 <- which(nonvirg_3==0                & cohort==12 )



### ARRIVAL OF SECOND PARTNERS

# Load data on dates of second partner:

arrivaldata <- read.dta("arrivals_R.dta")

# Match:

Asamp <- match(arrivaldata$aid, aid)

# Attach names of second partner data:

detach(data)
attach(arrivaldata)

# Indicators for nonvirgins searching in each period
# (without arrival of second partner that period)

NVsch.1 <- partnerq1 <= 139 & (partnerq2 > 139 | is.na(partnerq2) ) & cohort != 8
NVsch.2 <- partnerq1 <= 140 & (partnerq2 > 140 | is.na(partnerq2) ) & cohort != 8
NVsch.3 <- partnerq1 <= 141 & (partnerq2 > 141 | is.na(partnerq2) ) & cohort != 8
NVsch.4 <- partnerq1 <= 142 & (partnerq2 > 142 | is.na(partnerq2) ) & cohort != 8 & cohort != 12
NVsch.5 <- partnerq1 <= 143 & (partnerq2 > 143 | is.na(partnerq2) ) & cohort != 12
NVsch.6 <- partnerq1 <= 144 & (partnerq2 > 144 | is.na(partnerq2) ) & cohort != 12
NVsch.7 <- partnerq1 <= 145 & (partnerq2 > 145 | is.na(partnerq2) ) & cohort != 12

# Indicators for arrival of second partner:

two.1 <- ifelse(partnerq2 <= 139 & cohort != 8, 1, 0)
two.2 <- ifelse(partnerq2 == 140 & cohort != 8, 1, 0) 
two.3 <- ifelse(partnerq2 == 141 & cohort != 8, 1, 0)
two.4 <- ifelse(partnerq2 == 142 & cohort != 8 & cohort != 12, 1, 0) 
two.5 <- ifelse(partnerq2 == 143 & cohort != 12, 1, 0) 
two.6 <- ifelse(partnerq2 == 144 & cohort != 12, 1, 0) 
two.7 <- ifelse(partnerq2 == 145 & cohort != 12, 1, 0) 

two.1[is.na(two.1)] <- two.2[is.na(two.2)] <- two.3[is.na(two.3)] <- two.4[is.na(two.4)] <- 
  two.5[is.na(two.5)] <- two.6[is.na(two.6)] <- two.7[is.na(two.7)] <- 0

# Re-attach main data:

detach(arrivaldata)
attach(data)



### AGGREGATE STATE (vector of nonvirginity rates)
#   (called "h" or "hbar" rather than "Y")

# Import data:

h.all <- read.dta("agg_vec.dta") 

comlist <- as.character(h.all[h.all$t==1,"commid"])

# School-level data matrices for each period:

h.F94 <- as.matrix( h.all[h.all$t==0,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )
h.W95 <- as.matrix( h.all[h.all$t==1,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )
h.S95 <- as.matrix( h.all[h.all$t==2,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )
h.U95 <- as.matrix( h.all[h.all$t==3,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )
h.F95 <- as.matrix( h.all[h.all$t==4,
  c("hbar_b8","hbar_b9","hbar_b10","hbar_b11","hbar_g8","hbar_g9","hbar_g10","hbar_g11") ] )
h.W96 <- as.matrix( h.all[h.all$t==5,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )
h.S96 <- as.matrix( h.all[h.all$t==6,
  c("hbar_b9","hbar_b10","hbar_b11","hbar_b12","hbar_g9","hbar_g10","hbar_g11","hbar_g12") ] )

# Initial conditions (nonvirginity rates), made individual-level:
# (applies observed 9th grade nonvirginity rates for all grades)

hbar.0 <- matrix(NA, n, 2)

hbar.0[virgins.bHS,] <- h.F94[ match(commid[virgins.bHS], comlist),
  c("hbar_b9","hbar_g9") ]
hbar.0[virgins.gHS,] <- h.F94[ match(commid[virgins.gHS], comlist), 
  c("hbar_g9","hbar_b9") ]

hbar.0[c(virgins.b8,virgins.b7),] <- h.F94[ match(commid[c(virgins.b8,virgins.b7)], comlist), 
  c("hbar_b9","hbar_g9") ]
hbar.0[c(virgins.g8,virgins.g7),] <- h.F94[ match(commid[c(virgins.g8,virgins.g7)], comlist), 
  c("hbar_g9","hbar_b9") ]

# Individual-level data matrices for surviving virgins in each period:

h.b9.F94 <- h.F94[ match(commid[virgins.b9[vov.b9.F94]], comlist), ]
h.b10.F94 <- h.F94[ match(commid[virgins.b10[vov.b10.F94]], comlist), ]
h.b11.F94 <- h.F94[ match(commid[virgins.b11[vov.b11.F94]], comlist), ]
h.b12.F94 <- h.F94[ match(commid[virgins.b12[vov.b12.F94]], comlist), ]

h.g9.F94 <- h.F94[ match(commid[virgins.g9[vov.g9.F94]], comlist), ]
h.g10.F94 <- h.F94[ match(commid[virgins.g10[vov.g10.F94]], comlist), ]
h.g11.F94 <- h.F94[ match(commid[virgins.g11[vov.g11.F94]], comlist), ]
h.g12.F94 <- h.F94[ match(commid[virgins.g12[vov.g12.F94]], comlist), ]

h.b9.W95 <- h.W95[ match(commid[virgins.b9[vov.b9.W95]], comlist), ]
h.b10.W95 <- h.W95[ match(commid[virgins.b10[vov.b10.W95]], comlist), ]
h.b11.W95 <- h.W95[ match(commid[virgins.b11[vov.b11.W95]], comlist), ]
h.b12.W95 <- h.W95[ match(commid[virgins.b12[vov.b12.W95]], comlist), ]

h.g9.W95 <- h.W95[ match(commid[virgins.g9[vov.g9.W95]], comlist), ]
h.g10.W95 <- h.W95[ match(commid[virgins.g10[vov.g10.W95]], comlist), ]
h.g11.W95 <- h.W95[ match(commid[virgins.g11[vov.g11.W95]], comlist), ]
h.g12.W95 <- h.W95[ match(commid[virgins.g12[vov.g12.W95]], comlist), ]

h.b9.S95 <- h.S95[ match(commid[virgins.b9[vov.b9.S95]], comlist), ]
h.b10.S95 <- h.S95[ match(commid[virgins.b10[vov.b10.S95]], comlist), ]
h.b11.S95 <- h.S95[ match(commid[virgins.b11[vov.b11.S95]], comlist), ]
h.b12.S95 <- h.S95[ match(commid[virgins.b12[vov.b12.S95]], comlist), ]

h.g9.S95 <- h.S95[ match(commid[virgins.g9[vov.g9.S95]], comlist), ]
h.g10.S95 <- h.S95[ match(commid[virgins.g10[vov.g10.S95]], comlist), ]
h.g11.S95 <- h.S95[ match(commid[virgins.g11[vov.g11.S95]], comlist), ]
h.g12.S95 <- h.S95[ match(commid[virgins.g12[vov.g12.S95]], comlist), ]

h.b9.U95 <- h.U95[ match(commid[virgins.b9[vov.b9.U95]], comlist), ]
h.b10.U95 <- h.U95[ match(commid[virgins.b10[vov.b10.U95]], comlist), ]
h.b11.U95 <- h.U95[ match(commid[virgins.b11[vov.b11.U95]], comlist), ]

h.g9.U95 <- h.U95[ match(commid[virgins.g9[vov.g9.U95]], comlist), ]
h.g10.U95 <- h.U95[ match(commid[virgins.g10[vov.g10.U95]], comlist), ]
h.g11.U95 <- h.U95[ match(commid[virgins.g11[vov.g11.U95]], comlist), ]

h.b8.F95 <- h.F95[ match(commid[virgins.b8[vov.b8.F95]], comlist), ]
h.b9.F95 <- h.F95[ match(commid[virgins.b9[vov.b9.F95]], comlist), ]
h.b10.F95 <- h.F95[ match(commid[virgins.b10[vov.b10.F95]], comlist), ]
h.b11.F95 <- h.F95[ match(commid[virgins.b11[vov.b11.F95]], comlist), ]

h.g8.F95 <- h.F95[ match(commid[virgins.g8[vov.g8.F95]], comlist), ]
h.g9.F95 <- h.F95[ match(commid[virgins.g9[vov.g9.F95]], comlist), ]
h.g10.F95 <- h.F95[ match(commid[virgins.g10[vov.g10.F95]], comlist), ]
h.g11.F95 <- h.F95[ match(commid[virgins.g11[vov.g11.F95]], comlist), ]

h.b8.W96 <- h.W96[ match(commid[virgins.b8[vov.b8.W96]], comlist), ]
h.b9.W96 <- h.W96[ match(commid[virgins.b9[vov.b9.W96]], comlist), ]
h.b10.W96 <- h.W96[ match(commid[virgins.b10[vov.b10.W96]], comlist), ]
h.b11.W96 <- h.W96[ match(commid[virgins.b11[vov.b11.W96]], comlist), ]

h.g8.W96 <- h.W96[ match(commid[virgins.g8[vov.g8.W96]], comlist), ]
h.g9.W96 <- h.W96[ match(commid[virgins.g9[vov.g9.W96]], comlist), ]
h.g10.W96 <- h.W96[ match(commid[virgins.g10[vov.g10.W96]], comlist), ]
h.g11.W96 <- h.W96[ match(commid[virgins.g11[vov.g11.W96]], comlist), ]

h.b8.S96 <- h.S96[ match(commid[virgins.b8[vov.b8.S96]], comlist), ]
h.b9.S96 <- h.S96[ match(commid[virgins.b9[vov.b9.S96]], comlist), ]
h.b10.S96 <- h.S96[ match(commid[virgins.b10[vov.b10.S96]], comlist), ]
h.b11.S96 <- h.S96[ match(commid[virgins.b11[vov.b11.S96]], comlist), ]

h.g8.S96 <- h.S96[ match(commid[virgins.g8[vov.g8.S96]], comlist), ]
h.g9.S96 <- h.S96[ match(commid[virgins.g9[vov.g9.S96]], comlist), ]
h.g10.S96 <- h.S96[ match(commid[virgins.g10[vov.g10.S96]], comlist), ]
h.g11.S96 <- h.S96[ match(commid[virgins.g11[vov.g11.S96]], comlist), ]



### SAVE

save.image("analyticfile.RData")
