/* Extract month of first sex from raw data files, create quarterly panel. */



// IMPORT WAVE 1

* Import data: 
use aid commid imonth iyear bio_sex h1gi20 h1co1 h1co2* using allwave1
destring commid, replace

* Merge in-school data:
sort aid
merge aid using created/inschool, nokeep keep(s1 s2 s3)
rename _m mergeInS

* Use in-school data to identify missing grade information:
gen byte cohort = h1gi20
replace cohort = s3 if cohort > 12 & s3 < 13
label variable cohort "Grade in 1994-95 academic year"

* Basic sample restrictions:
drop if bio_sex > 2
drop if iyear == 94
drop if cohort == 6 | cohort > 12

keep aid-h1gi20 h1co1 h1co2* cohort

* Format time:
gen t = yq(1900+iyear, int((imonth+2)/3))
format t %tq

* Make panel dataset:
destring aid, gen(id)
tsset id t, quarterly
tab imonth t

* Add rows for each quarter:
count
set obs 20386
* (adds a dummy observation, used to define the last quarter)
replace t = 138 if t == .
drop if t == .
tsfill, full

* Drop any quarters after interview:
drop if L1.imonth ~= .
drop if L2.imonth ~= .
drop if L3.imonth ~= .
drop if L4.imonth ~= .

* Fill in variables identifying groups:
foreach var of varlist commid bio_sex cohort {
  replace `var' = F1.`var' if `var' == .
  replace `var' = F2.`var' if `var' == .
  replace `var' = F3.`var' if `var' == .
  replace `var' = F4.`var' if `var' == .
  replace `var' = F5.`var' if `var' == .
  }

* Drop the dummy observation 
* (was used to create t = 138):
drop if id == .

save temp, replace



// IMPORT WAVE 2

* Import data: 
use aid imonth2 iyear2 h2co2 h2co3* using wave2

* Format time:
gen t = yq(1900+iyear2, int((imonth2+2)/3))
format t %tq

* Make panel dataset:
destring aid, gen(id)
tsset id t, quarterly
tab imonth2 t

* Combine w/Wave I:
append using temp
tsset

* Drop observations without a match from Wave 1:
by id: egen min_t = min(t)
drop if min_t > 138
drop min_t

* Fill in observations and group identifiers:
tsfill
foreach var of varlist commid bio_sex cohort {
  replace `var' = L1.`var' if `var' == .
  }
* (note one lag can fill a series of missing values b/c observations are sorted by t)



// CREATE QUARTERLY PANEL OF VIRGINITY STATUSES

* Recode missing values in year and month variables:
foreach var of varlist h1co2y h1co2m h2co3m {
  replace `var' = . if `var' >= 96
  }
replace h2co3y = . if h2co3y >= 996

* Generate quarter of first sex:
gen h1co2t1 = yq(1900+h1co2y, int((h1co2m+2)/3))
format h1co2t1 %tq
gen h2co3t1 = yq(1900+h2co3y, int((h2co3m+2)/3))
format h2co3t1 %tq

* Create and populate virginity status variable for each period:
* (note that reports from first wave are not replaced by second wave)

foreach var of varlist h1co2t1 h2co3t1 {
  replace `var' = F1.`var' if `var' == .
  replace `var' = F2.`var' if `var' == .
  replace `var' = F3.`var' if `var' == .
  replace `var' = F4.`var' if `var' == .
  replace `var' = F5.`var' if `var' == .
  replace `var' = F6.`var' if `var' == .
  replace `var' = F7.`var' if `var' == .
  replace `var' = F8.`var' if `var' == .
  replace `var' = L1.`var' if `var' == .
  }

gen byte nonvirg = 0

foreach var of varlist h1co2t1 h2co3t1 {
  replace nonvirg = 1 if `var' <= t
  }

* NOTE: This uses the earliest date of first sex reported in either Wave 1 or Wave 2.
*   However among initial virgins only 68 observations have a discrepancy 
*   where the date reported in Wave 2 is earlier.

* Save:
tsset
compress
save created/quarterly, replace
rm temp.dta
