/* Extract data on the arrival of second sexual partner. */



// IMPORT RAW DATA

* A) Wave II

* Load: 

use aid imonth2 iyear2 h2co2 h2co3* h2ri* h2nr* h2rx* using wave2

global sex      h2ri36* h2rx36* h2nr41*
global sexstart h2ri37* h2rx37* h2nr42*

keep aid imonth2 iyear2 h2co2 h2co3* $sex $sexstart

sort aid
save temp, replace

* B) Wave I

* Load: 

use aid commid imonth iyear bio_sex h1gi20 h1co1 h1co2* h1ri* h1nr* h1rx* using allwave1

global sex      h1ri24* h1rx24* h1nr22*
global sexstart h1ri25* h1rx25* h1nr23*

keep aid-h1gi20 h1co1 h1co2* $sex $sexstart

* Basic sample restrictions:

drop if bio_sex > 2
drop if iyear == 94
drop if h1gi20 > 12

* Combine w/Wave II:

sort aid
merge aid using temp, nokeep
rename _m mergeW2

rm temp.dta



// DATE OF FIRST SEX

* Recode missing values:

foreach var of varlist h1co2y h1co2m h2co3m {
  replace `var' = . if `var' >= 96
  }
replace h2co3y = . if h2co3y >= 996

* Quarter of first sex:

gen int h1co2tq1 = yq(1900+h1co2y, int((h1co2m+2)/3))
format h1co2tq1 %tq
gen int h2co3tq1 = yq(1900+h2co3y, int((h2co3m+2)/3))
format h2co3tq1 %tq

gen int anysex = min(h1co2tq1, h2co3tq1)
format anysex %tq

* Month of first sex:

gen int h1co2tm1 = ym(1900+h1co2y, h1co2m)
format h1co2tm1 %tm
gen int h2co3tm1 = ym(1900+h2co3y, h2co3m)
format h2co3tm1 %tm



// DATES OF SEXUAL PARTNERS

* Recode missing values (Wave I):

foreach var of varlist $sexstart {
  replace `var' = . if `var' >= 96
  }

* Quarter that each sexual relationship began (Wave I):

foreach prefix in h1ri25 h1rx25 h1nr23 {
  forvalues partner = 1/3 {
    gen `prefix'tq`partner' = yq(1900+`prefix'y`partner', int((`prefix'm`partner'+2)/3))
    format `prefix'tq`partner' %tq
    }
  }

* Affirm vaginal intercourse:

foreach prefix in h1ri h1rx {
  forvalues partner = 1/3 {
    replace `prefix'25tq`partner' = . if `prefix'24a`partner' ~= 1
    }
  }
forvalues partner = 1/3 {
  replace h1nr23tq`partner' = . if h1nr22_`partner' ~= 1
  }

* Month that each sexual relationship began (Wave I):

foreach prefix in h1ri25 h1rx25 h1nr23 {
  forvalues partner = 1/3 {
    gen `prefix'tm`partner' = ym(1900+`prefix'y`partner', `prefix'm`partner')
    format `prefix'tm`partner' %tm
    }
  }

* Affirm vaginal intercourse:

foreach prefix in h1ri h1rx {
  forvalues partner = 1/3 {
    replace `prefix'25tm`partner' = . if `prefix'24a`partner' ~= 1
    }
  }
forvalues partner = 1/3 {
  replace h1nr23tm`partner' = . if h1nr22_`partner' ~= 1
  }

* Recode missing values (Wave II):

foreach var of varlist h2r*m* h2n*m* {
  replace `var' = . if `var' >= 96
  }

* Quarter that each sexual relationship began (Wave II):

foreach var of varlist h2r*y* h2n*y*  {
  replace `var' = . if `var' >= 996
  }

foreach prefix in h2ri37 h2rx37 h2nr42 {
  forvalues partner = 1/3 {
    gen `prefix'tq`partner' = yq(1900+`prefix'y`partner', int((`prefix'm`partner'+2)/3))
    format `prefix'tq`partner' %tq
    }
  }

* Affirm vaginal intercourse:

foreach prefix in h2ri h2rx {
  forvalues partner = 1/3 {
    replace `prefix'37tq`partner' = . if `prefix'36_`partner' ~= 1
    }
  }
forvalues partner = 1/3 {
  replace h2nr42tq`partner' = . if h2nr41_`partner' ~= 1
  }

* Month that each sexual relationship began (Wave II):

foreach prefix in h2ri37 h2rx37 h2nr42 {
  forvalues partner = 1/3 {
    gen `prefix'tm`partner' = ym(1900+`prefix'y`partner', `prefix'm`partner')
    format `prefix'tm`partner' %tm
    }
  }

* Affirm vaginal intercourse (Wave II):

foreach prefix in h2ri h2rx {
  forvalues partner = 1/3 {
    replace `prefix'37tm`partner' = . if `prefix'36_`partner' ~= 1
    }
  }
forvalues partner = 1/3 {
  replace h2nr42tm`partner' = . if h2nr41_`partner' ~= 1
  }

* Clean up variables:

drop h1co1-h1nr23y3 h2co2-h2nr42y3

compress
sort aid



// PICK THE SAMPLE FOR DATA ON SECOND PARTNERS
/* Initial virgins who report same period for first sex in both kinds of questions: 
   date of first sex in general and with the earliest listed partner.  */

* A) Using quarter of first sex

* Find the earliest quarter of first sex with a listed partner:

gen int partsex = h1ri25tq1
format partsex %tq

foreach var of varlist h*r*tq* h*n*tq* {
  replace partsex = min(partsex, `var')
  }

* Analyze differences with quarter of first sex in general:

count if anysex >= 139 & anysex ~= .
count if anysex >= 139 & anysex ~= . & partsex ~= .
count if anysex >= 139 & anysex ~= . & partsex == anysex
count if                 anysex ~= . & partsex == anysex

gen int diff = partsex-anysex
tab diff if anysex >= 139

* B) Using month of first sex

* Month of first sex from the general questions:

gen int anysex_m = min(h1co2tm1, h2co3tm1)
format anysex_m %tm

* Find the earliest month of first sex with a listed partner:

gen int partsex_m = h1ri25tm1
format partsex_m %tm

foreach var of varlist h*r*tm* h*n*tm* {
  replace partsex_m = min(partsex_m, `var')
  }

* Analyze differences:

count if anysex >= 139 & anysex_m ~= .
count if anysex >= 139 & anysex_m ~= . & partsex_m ~= .
count if anysex >= 139 & anysex_m ~= . & partsex_m == anysex_m
count if                 anysex_m ~= . & partsex_m == anysex_m

count if anysex >= 139 & anysex_m ~= . & abs(partsex_m - anysex_m) <= 3

gen int diff_m = partsex_m-anysex_m
tab diff_m if anysex >= 139

* Keep if reported month of first sex with a listed partner is within 3 months of reported first sex in general:

keep if anysex >= 139 & anysex_m ~= . & abs(partsex_m - anysex_m) <= 3



// REMOVE DOUBLE-COUNTED PARTNERS
* (if same partner is reported in both waves)

* Rename variables (for reshape command)
* (11 = W1, ri; 12 W1, rx; 13 = W1, nr; 2x = W2, xx)

renpfix h1ri25tm partnerm11
renpfix h1rx25tm partnerm12
renpfix h1nr23tm partnerm13
renpfix h2ri37tm partnerm21
renpfix h2rx37tm partnerm22
renpfix h2nr42tm partnerm23

renpfix h1ri25tq partnerq11
renpfix h1rx25tq partnerq12
renpfix h1nr23tq partnerq13
renpfix h2ri37tq partnerq21
renpfix h2rx37tq partnerq22
renpfix h2nr42tq partnerq23

* Make into a panel:

reshape long partnerm partnerq, i(aid)
drop if partnerq==.

* Wave indicator:

gen byte wave = int(_j/100)

* Count partners:

sort aid partnerm _j

by aid: gen byte npart = _n

* Count total observations: 

tab npart
tab h1gi20 bio if n==1
tab h1gi20 bio if n==2
tab h1gi20 bio if n==1 & mergeW2==3
tab h1gi20 bio if n==2 & mergeW2==3

* Tag multiple reports of first sex with partners in same month:

duplicates tag aid partnerm, gen(dup)

tab npart dup
tab _j dup

* Check for same month of first sex reported in separate waves:

sort aid partnerm _j
by aid: gen byte prevwave = wave[_n-1]
by aid: gen int prevmth = partnerm[_n-1]

tab _j if n==2 & dup > 0
tab _j if n==2 & dup > 0 & wave~=prevwave
tab _j if n==2 & partnerm==prevmth & wave~=prevwave

* Drop duplicates (same month reported in first and second wave):
* (only drop if second ever partner is reported in same month as first ever partner, 
*  and these two partners are reported in different waves -- hence, the same partner)

drop if n==2 & partnerm==prevmth & wave~=prevwave
drop npart dup wave prev*

* Re-count partners:

sort aid partnerm _j
by aid: gen byte npart = _n

tab npart



// MERGE WITH ESTIMATION SAMPLE AND EXPORT

* Limit to first and second partners:

keep if npart==1 | npart==2

* Reshape:

rename _j source

reshape wide partnerm partnerq source, i(aid) j(npart)

* Merge:

destring aid, gen(id)
sort id

merge id using created/dynamic_R.dta
tab _m

* Check sample sizes:

tab h1gi20 bio if partnerq1 ~= . & _m==3
tab h1gi20 bio if partnerq2 ~= . & _m==3

tab h1gi20 bio if partnerq2==146
* (won't use 10 second partners from 1996q3, after study period)

* Check truncated durations:

gen int lag = partnerq2-partnerq1

tab lag bio if _m==3

* Cut down to useable sample:

keep if _m==3

drop if nonvirg_7 == 0
drop if partnerq1 == 146

drop if cohort==7
drop if cohort==8 & partnerq1 < 143
drop if cohort==12 & partnerq1 > 141

* Check sample size:

tab h1gi20 bio if partnerq1 ~= .
tab h1gi20 bio if partnerq2 ~= .

* Save:

keep aid partnerq1 partnerq2 bio_sex cohort nonvirg* id
order id cohort bio_sex

sort id
saveold created/arrivals_R.dta, replace
