// SETUP

set more off



// IMPORT AND CONVERT VARIABLE VALUES

use eqsim.dta

* Convert cohort:

decode cohort, gen(test)
destring test, replace force
replace cohort=test

drop test

* Convert commid:

decode commid, gen(test)
destring test, replace force
replace commid=test

drop test

* Convert virginity status indicators:

foreach var of varlist nonvirg_* {
  replace `var' = `var' - 1
  label drop `var'
  }

* Remove labels:

label drop _all
compress



// COLLAPSE AND MAKE SUPPLY GROUPS

* Collapse to aggregate by school-grade-sex cohorts:

collapse nonvirg_* (count) pop_ = nonvirg_1sim, by(commid cohort bio_sex)

* Convert into panel:

reshape long nonvirg_, i(commid cohort bio_sex) string
gen str1 t = _j
destring t, replace force
drop _j

replace t = t+138
format t %tq

* Reshape dataset so that each observation has both genders:

rename nonvirg_ hbar_ 

reshape wide hbar_ pop_, i(commid cohort t) j(bio_sex)

* Use time series operators to make supply groups:
* (i.e., certain grades of the opposite gender, the endogenous "market")

gen com_t = commid*1000 + t
tsset com_t cohort

gen market0_2 = hbar_1
gen market1_2 = F1.hbar_1
gen market2_2 = F2.hbar_1
gen market0_1 = hbar_2
gen market1_1 = L1.hbar_2
gen market2_1 = F1.hbar_2

* Reshape back to have separate observations by gender:

drop com_t
reshape long hbar_ pop_ market0_ market1_ market2_, i(commid cohort t) j(bio_sex)



// VARIABLES

* Clean up variable names:

rename bio_sex gen
rename hbar_ hbar
rename pop_ pop
forvalues N = 0/2 {
  rename market`N'_ market`N'
  }

gen byte grd = cohort + (t > 142)

* Replace missing market supplies with zeros where appropriate:

replace market1 = 0 if gen == 1 &  grd == 9
replace market2 = 0 if gen == 1 &  grd == 12
replace market1 = 0 if gen == 2 &  grd == 12
replace market2 = 0 if gen == 2 & (grd == 11 | grd ==12)

* Identifier for school-grade-sex groups:

gen aggid = 1000*commid + 10*cohort + gen



// QUARTERLY FILE

* Generate quarterly lags of peer and supply group rates:

tsset aggid t

gen ownlag = L1.hbar
gen firstdiff = D1.hbar
gen mktlag0 = L1.market0
gen mktlag1 = L1.market1
gen mktlag2 = L1.market2

* Save:

saveold agg_qtr_sim, replace



// ANNUAL FILE

* Replace quarterly lags with annual lags:

drop ownlag-mktlag2

gen ownlag = L4.hbar
gen firstdiff = S4.hbar
gen mktlag0 = L4.market0
gen mktlag1 = L4.market1
gen mktlag2 = L4.market2

* Save:

saveold agg_ann_sim, replace



// QUIT

exit
