# This program accomplishes a parametric bootstrap using the estimated
#  variance matrix of the structural parameters.

# The sections below are run interactively (using 'screen' to run in background).



### A) SETUP

# Number of draws:

S.conf <- 1000

# Normal draws using estimated variance:

C.theta <- chol(var.mix)
Z.theta <- matrix( rnorm(length(param)*S.conf), S.conf, length(param) )
N.theta <- Z.theta %*% C.theta

# Save draws in main file:

save.image("workingfile.RData")



### B) BOOTSTRAP SIMULATION

# Storage:

b9.sim <- g9.sim <- matrix( nrow=S.conf, ncol=16 )

# Loop:

for (s in 1:S.conf)  {
  theta <- param + N.theta[s,]
  sim.2types(theta) -> temp
  b9.sim[s,] <- temp[,1]
  g9.sim[s,] <- temp[,2]
  print(s)
  }

# Results:

b9.S98rank <- order(b9.sim[,16])
g9.S98rank <- order(g9.sim[,16])

cbind( b9.sim[b9.S98rank[25],] , b9.sim[b9.S98rank[975],] )
cbind( g9.sim[g9.S98rank[25],] , g9.sim[g9.S98rank[975],] )

# Save (*modify filename*):

save(C.theta, Z.theta, b9.sim, g9.sim, file="CI-<NAME>.RData")

quit(save="no")



### C) COUNTERFACTUALS

# Open modified dataset for the counterfactual:
# (created by 'counterfactual.R')

load("sim.RData")
attach(data)

# Collect parameter vector:

param <- c(a1.b, g.b, W.b[2:3],v.b[2:3],
           a1.g, g.g, W.g[2:3],v.g[2:3],
  lambda.b9[1],lambda.b10[1],lambda.b11[1],lambda.b12[1],lambda.b10[2:4], 
  lambda.g9[1],lambda.g10[1],lambda.g11[1],lambda.g12[1],lambda.g10[2:4],
  pi3.b, pi3.g)

# Run code in Section B above...
