### LOAD QUARTERLY TRANSITION DATA

# Load:

library(foreign)
data <- read.dta("agg_qtr_sim.dta")
attach(data)

# Sample restriction:

aggsample <- which(grd > 8 & grd < 13 & (cohort<12 | t<142) )

# Make categorical variables:

grd <- as.factor(grd)
gen <- as.factor(gen)
t   <- as.factor(t)
com <- as.factor(commid)

# Nonlinear term:

lagsq <- ownlag^2



### ESTIMATE APPROXIMATION

# OLS:

OLS <- lm(hbar ~ grd*gen + ownlag*gen + lagsq*gen 
  + mktlag0*gen + mktlag1*gen + mktlag2*gen - 1,
  weights=pop, subset=aggsample)



### QUARTERLY TRANSITION MATRIX

# Extract components:

B.0 <- OLS$coef[c("grd9", "grd10", "grd11", "grd12")]
G.0 <- B.0 + OLS$coef["gen2"]
G.0 <- G.0 + c(0, 
  OLS$coef[c("grd10:gen2", "grd11:gen2", "grd12:gen2")] )

B.own <- OLS$coef["ownlag"]*diag(4)
G.own <- B.own + OLS$coef["gen2:ownlag"]*diag(4)

B.sq <- OLS$coef["lagsq"]*diag(4)
G.sq <- B.sq + OLS$coef["gen2:lagsq"]*diag(4)

B.m0 <- OLS$coef["mktlag0"]*diag(4)
B.m1 <- OLS$coef["mktlag1"]*diag(3)
B.m2 <- OLS$coef["mktlag2"]*diag(3)

B.m1 <- rbind(0,B.m1); B.m1 <- cbind(B.m1,0)
B.m2 <- rbind(B.m2,0); B.m2 <- cbind(0,B.m2)
B.mkt <- B.m0 + B.m1 + B.m2

G.m0 <- (OLS$coef["mktlag0"] + OLS$coef["gen2:mktlag0"]) * diag(4)
G.m1 <- (OLS$coef["mktlag1"] + OLS$coef["gen2:mktlag1"]) * diag(3)
G.m2 <- (OLS$coef["mktlag2"] + OLS$coef["gen2:mktlag2"]) * diag(2)

G.m1 <- rbind(G.m1,0); G.m1 <- cbind(0,G.m1)
G.m2 <- rbind(G.m2,0,0); G.m2 <- cbind(0,0,G.m2)
G.mkt <- G.m0 + G.m1 + G.m2

Psi.b <- cbind(B.0,B.own,B.mkt,B.sq,0,0,0,0)
Psi.g <- cbind(G.0,G.mkt,G.own,0,0,0,0,G.sq)

Psi <- rbind(Psi.b, Psi.g)

# Store quarterly matrix:

Psi -> Psi.qtr



### LOAD ANNUAL TRANSITION DATA

rm(grd, gen, t, com, lagsq)

# Load:

library(foreign)
data.ann <- read.dta("agg_ann_sim.dta")
detach(data)
attach(data.ann)

# Sample restriction:

aggsample <- which(grd > 8 & grd < 13 & (cohort<12 | t<142) )

# Summer sample (used in forecasts of new cohorts):

summersamp <- which(grd==9 & t==142 )

# Categorical variables:

grd <- as.factor(grd)
gen <- as.factor(gen)
t   <- as.factor(t)
com <- as.factor(commid)

# Constructed variables:

lagsq <- ownlag^2



### ESTIMATE ANNUAL APPROXIMATIONS

# Annual forecast:

OLS <- lm(hbar ~ grd*gen + ownlag*gen + lagsq*gen 
  + mktlag0*gen + mktlag1*gen + mktlag2*gen - 1,
  weights=pop, subset=aggsample)

# Forecast for new cohorts using 9th grade in 1996:

new.coh <- lm(hbar ~ gen*ownlag - 1,
  weights=pop, subset=summersamp)



### ANNUAL TRANSITION MATRICES

# Extract components:

B.0 <- OLS$coef[c("grd10", "grd11", "grd12")]
G.0 <- B.0 + OLS$coef["gen2"]
G.0 <- G.0 + OLS$coef[c("grd10:gen2", "grd11:gen2", "grd12:gen2")]

B.own <- OLS$coef["ownlag"]*diag(3)
G.own <- B.own + OLS$coef["gen2:ownlag"]*diag(3)

B.sq <- OLS$coef["lagsq"]*diag(3)
G.sq <- B.sq + OLS$coef["gen2:lagsq"]*diag(3)

B.m0 <- OLS$coef["mktlag0"]*diag(4)
B.m1 <- OLS$coef["mktlag1"]*diag(3)
B.m2 <- OLS$coef["mktlag2"]*diag(3)

B.m1 <- rbind(0,B.m1); B.m1 <- cbind(B.m1,0)
B.m2 <- rbind(B.m2,0); B.m2 <- cbind(0,B.m2)
B.mkt <- B.m0 + B.m1 + B.m2

G.m0 <- (OLS$coef["mktlag0"] + OLS$coef["gen2:mktlag0"]) * diag(4)
G.m1 <- (OLS$coef["mktlag1"] + OLS$coef["gen2:mktlag1"]) * diag(3)
G.m2 <- (OLS$coef["mktlag2"] + OLS$coef["gen2:mktlag2"]) * diag(2)

G.m1 <- rbind(G.m1,0); G.m1 <- cbind(0,G.m1)
G.m2 <- rbind(G.m2,0,0); G.m2 <- cbind(0,0,G.m2)
G.mkt <- G.m0 + G.m1 + G.m2

B.mkt <- B.mkt[1:3,]
G.mkt <- G.mkt[1:3,]

Psi.b <- cbind(B.0, B.own,0, B.mkt, B.sq,0, 0,0,0,0)
Psi.g <- cbind(G.0, G.mkt, G.own,0, 0,0,0,0, G.sq,0)

Psi <- rbind(0,Psi.b,0,Psi.g)
Psi[1,2] <- 1; Psi[5,6] <- 1

# Store annual matrix:

Psi -> Psi.ann

# Matrix to shift up a grade and add new cohort:

B.own <- cbind(rbind(0,diag(3)),0)
B.own[1,1] <- 1/new.coh$coef["ownlag"]
G.own <- cbind(rbind(0,diag(3)),0)
G.own[1,1] <- 1/(new.coh$coef["ownlag"] + new.coh$coef["gen2:ownlag"])

B.0 <- c(-new.coh$coef["gen1"]/new.coh$coef["ownlag"], 0,0,0)
G.0 <- c(-new.coh$coef["gen2"]/(new.coh$coef["ownlag"] + new.coh$coef["gen2:ownlag"]), 0,0,0)

Psi.chg <- rbind(cbind(B.own,0,0,0,0),cbind(0,0,0,0,G.own) )
Psi.chg <- cbind(c(B.0,G.0), Psi.chg)



### FORECASTING FUNCTIONS (psi)

# Quarterly:

psi.qtr <- function(h)  cbind(1,h,h^2) %*% t(Psi.qtr)            # FOR ROW VECTOR OR MATRIX 

# Annual:

psi.ann <- function(h)  cbind(1,h,h^2) %*% t(Psi.ann)            # FOR ROW VECTOR OR MATRIX 

# New cohort:

psi.chg <- function(h)  {                                        # FOR ROW VECTOR OR MATRIX
  h.new <- cbind(1,h,h^2) %*% t(Psi.qtr)
  h.chg <- cbind(1,h.new) %*% t(Psi.chg)                         # (subtracts avg. ann. growth)
  h.chg <- pmax(h.chg,0)
  h.chg
  }

