### LOAD DATA FOR COUNTERFACTUAL

load("sim.RData")
attach(data)



### NEW SIMULATION

# Run likelihood function to revise auxiliary parameters:
# (not needed on first iteration)

for (i in 1:3)  {
print( like.final(
c(a1.b,g.b, W.b,v.b, a1.g,g.g, W.g,v.g,
  lambda.b9[1],lambda.b10[1],lambda.b11[1],lambda.b12[1],lambda.b10[2:4], 
  lambda.g9[1],lambda.g10[1],lambda.g11[1],lambda.g12[1],lambda.g10[2:4],
  pi2.b,pi3.b, pi2.g,pi3.g)
  ) , 8)
}

# Simulate outcomes:

attach(Draws.1)

supersim( 
c(a1.b,g.b, W.b,v.b, a1.g,g.g, W.g,v.g,
  lambda.b9[1],lambda.b10[1],lambda.b11[1],lambda.b12[1],lambda.b10[2:4], 
  lambda.g9[1],lambda.g10[1],lambda.g11[1],lambda.g12[1],lambda.g10[2:4],
  pi2.b,pi3.b, pi2.g,pi3.g)
  ) -> temp

# Export simulated data:

library(foreign)

write.dta(as.data.frame(cbind(commid,cohort,bio_sex, temp$ind[,1:8]) ), 
  "eqsim.dta", version=7)

# Save:

save.image(file="sim.RData")
quit(save="no")



### GENERATE VECTOR OF AGGREGATES (in Stata)

# At the Linux prompt:

# stata -q do ~/data/replication/code/simulation/agg_qtr_sim.do



### ESTIMATE BELIEFS APPROXIMATION

source("~/data/replication/code/simulation/eqapprox_est.R")

# Save new approximation:
# (update file name with number of iteration)

save( list=c("Psi.qtr", "Psi.ann", "Psi.chg", "psi.qtr", "psi.ann", "psi.chg"), 
  file="eqapprox_sim<N>.RData" )



### CHECK FOR CONVERGENCE 

# Compare w/previous approximation:

alt <- new.env()

load("eqapprox_sim<N-1>.RData", alt)

Psi.qtr - alt$Psi.qtr
Psi.ann - alt$Psi.ann

(Psi.qtr - alt$Psi.qtr) / alt$Psi.qtr
(Psi.ann - alt$Psi.ann) / alt$Psi.ann

###
# If the approximation has not converged, go back to the top of this program.
###
# If the approximation has converged, do the following...
###

# Save final approximation (when converged):
# (insert counterfactual number -- 1, 2, 3)

save( list=c("Psi.qtr", "Psi.ann", "Psi.chg", "psi.qtr", "psi.ann", "psi.chg"), 
  file="eqapprox_fin<S>.RData" )

# Load simulation data:

load("sim.RData")
attach(data)

# Save:

save.image(file="sim.RData")

