# Load analytic files and define starting values of structural and auxiliary parameters.



### LOAD DATA

load("analyticfile.RData")

attach(data)

load("eqapprox_all.RData")



### FUNCTIONS

# Distribution of types:

pifun <- function(pi2, pi3) function(chars) {
  denom <- 1 + exp(chars %*% pi2) + exp(chars %*% pi3)
  indep <- cbind( exp(chars %*% pi2)/denom, exp(chars %*% pi3)/denom )
  cbind(1 - indep[,1] - indep[,2], indep)
  }

# Arrival rate:

Match <- function(lambda) function(N)  {
  plogis( cbind(1,N) %*% lambda )
  }

# Conditional expectation of epsilon:

Eeps <- function(x)  {
  ifelse(x > -35, dnorm(x) / pnorm(x), -x)
  }



### STARTING VALUES OF STRUCTURAL PARAMETERS

# Flow payoffs:

g.b <- 0.8;  g.g <- 0.3
# (preference interaction)

a1.b <- a1.g <- 0.1
# (linear age parameter)

a.b9 <- a.b10 <- a.b11 <- a.b12 <- 0 
a.g9 <- a.g10 <- a.g11 <- a.g12 <- 0
# (unused grade-specific intercepts)

# Arrival rates:

lambda.b12 <- c(-1, 0.5,0.4);     lambda.g12 <- c(-0.5, 1)       
lambda.b11 <- c(-1, 0.5,0.4,0.3); lambda.g11 <- c(-0.7, 0.8,0.6)
lambda.b10 <- c(-1, 0.5,0.4,0.3); lambda.g10 <- c(-1  , 0.8,0.6,0.5)
lambda.b9  <- c(-1, 0.5,0.3);     lambda.g9  <- c(-1  , 0.8,0.6,0.5)

# (boys: same, one down, one up; girls: same, one up, two up)

# Unobserved types:
# (the code allows for three types, but only two are used)

W.b <- c(0,-0.05,0.05);  W.g <- c(0,-0.05,0.05)
names(W.b) <- c("W.b", "Lo", "Hi"); names(W.g) <- c("W.g", "Lo", "Hi")

pi2.b <- c(-1, 0.1, -0.1, rep(0, length(indvars)) )
pi3.b <- c(-1, -0.1, 0.1, rep(0, length(indvars)) ) 

pi2.g <- c(-1, 0.15, -0.05, rep(0, length(indvars)) )
pi3.g <- c(-1, -0.05, 0.15, rep(0, length(indvars)) ) 

# Future discounted payoffs:

v.b <- v.g <- c(0,-0.5, 0.5)

d <- 0  #  (not used, would allow norms effect to continue after high school)

B <- 0.9



### STARTING VALUES FOR CHOICE APPROXIMATION
#  (Note: These use additional variables, not in the final version.)

hbar.S95 <- h.S95[ match(commid, comlist), ]

# Estimate boys:

Dpred.b.S12 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_b12"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==12 & bio_sex==1)$coef
Dpred.b.S11 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_b11"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==11 & bio_sex==1)$coef
Dpred.b.S10 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_b10"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==10 & bio_sex==1)$coef
Dpred.b.S9 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_b9"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort== 9 & bio_sex==1)$coef

# Estimate girls:

Dpred.g.S12 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_g12"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==12 & bio_sex==2)$coef
Dpred.g.S11 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_g11"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==11 & bio_sex==2)$coef
Dpred.g.S10 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_g10"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort==10 & bio_sex==2)$coef
Dpred.g.S9 <- 
  lm(nonvirg_3 ~ hbar.S95[,"hbar_g9"] + as.matrix(data[,indvars])
     + Xbar.pj, subset = cohort== 9 & bio_sex==2)$coef

rm(hbar.S95)

# Convert coefficient vectors to be conformable in model solver:

Dp2.b.S12 <- Dpred.b.S12[2]; Dpred.b.S12 <- Dpred.b.S12[-2]
Dp2.b.S11 <- Dpred.b.S11[2]; Dpred.b.S11 <- Dpred.b.S11[-2]
Dp2.b.S10 <- Dpred.b.S10[2]; Dpred.b.S10 <- Dpred.b.S10[-2]
Dp2.b.S9 <- Dpred.b.S9[2]; Dpred.b.S9 <- Dpred.b.S9[-2]

Dp2.g.S12 <- Dpred.g.S12[2]; Dpred.g.S12 <- Dpred.g.S12[-2]
Dp2.g.S11 <- Dpred.g.S11[2]; Dpred.g.S11 <- Dpred.g.S11[-2]
Dp2.g.S10 <- Dpred.g.S10[2]; Dpred.g.S10 <- Dpred.g.S10[-2]
Dp2.g.S9 <- Dpred.g.S9[2]; Dpred.g.S9 <- Dpred.g.S9[-2]

# Populate earlier quarters with same values:

Dpred.b.W12 <- Dpred.b.S12; Dp2.b.W12 <- Dp2.b.S12
Dpred.b.F12 <- Dpred.b.S12; Dp2.b.F12 <- Dp2.b.S12

Dpred.g.W12 <- Dpred.g.S12; Dp2.g.W12 <- Dp2.g.S12
Dpred.g.F12 <- Dpred.g.S12; Dp2.g.F12 <- Dp2.g.S12

Dpred.b.U11 <- Dpred.b.S11; Dp2.b.U11 <- Dp2.b.S11
Dpred.b.W11 <- Dpred.b.S11; Dp2.b.W11 <- Dp2.b.S11
Dpred.b.F11 <- Dpred.b.S11; Dp2.b.F11 <- Dp2.b.S11

Dpred.b.U10 <- Dpred.b.S10; Dp2.b.U10 <- Dp2.b.S10
Dpred.b.W10 <- Dpred.b.S10; Dp2.b.W10 <- Dp2.b.S10
Dpred.b.F10 <- Dpred.b.S10; Dp2.b.F10 <- Dp2.b.S10

Dpred.b.U9  <- Dpred.b.S9 ; Dp2.b.U9  <- Dp2.b.S9
Dpred.b.W9  <- Dpred.b.S9 ; Dp2.b.W9  <- Dp2.b.S9
Dpred.b.F9  <- Dpred.b.S9 ; Dp2.b.F9  <- Dp2.b.S9

Dpred.g.U11 <- Dpred.g.S11; Dp2.g.U11 <- Dp2.g.S11 
Dpred.g.W11 <- Dpred.g.S11; Dp2.g.W11 <- Dp2.g.S11 
Dpred.g.F11 <- Dpred.g.S11; Dp2.g.F11 <- Dp2.g.S11 

Dpred.g.U10 <- Dpred.g.S10; Dp2.g.U10 <- Dp2.g.S10
Dpred.g.W10 <- Dpred.g.S10; Dp2.g.W10 <- Dp2.g.S10
Dpred.g.F10 <- Dpred.g.S10; Dp2.g.F10 <- Dp2.g.S10

Dpred.g.U9  <- Dpred.g.S9 ; Dp2.g.U9  <- Dp2.g.S9
Dpred.g.W9  <- Dpred.g.S9 ; Dp2.g.W9  <- Dp2.g.S9
Dpred.g.F9  <- Dpred.g.S9 ; Dp2.g.F9  <- Dp2.g.S9
